from django.shortcuts import render_to_response, get_object_or_404, redirect
from django.template import RequestContext
from arartekomaps.settings import STATIC_URL
from arartekomaps.places.models import Place, Location, Category
from django.core.paginator import Paginator
from django.utils import translation
from django.utils.translation import ugettext_lazy as _

ACCESS_CHOICES = (
        ('', _('Any')),
        ('p', _('Practicable')),
        ('a', _('Accesible')),
    )

ACCESS_AREAS = (
    (_('aphysic'), 'aphysic'),
    (_('avisual'), 'avisual'),
    (_('aaudio'), 'aaudio'),
    (_('aintelec'), 'aintelec'),
    (_('aorganic'), 'aorganic')
)


def home(request):
    """"""
    template_name = 'home'
    hidesearch = True
    places = Place.objects.filter(is_public=True).order_by('?')[:5]
    return render_to_response('home.html',
        locals(), context_instance=RequestContext(request))


def filter(request):
    """ """
    hidesearch = True
    action = 'filter'

    places = Place.objects.filter(is_public=True)

    # City
    try:
        city = int(request.GET.get('city', 0))
        if city:
            city_obj = Location.objects.get(pk=city)
            places = places.filter(city=city_obj)
    except:
        pass

    # Category
    try:
        cat = int(request.GET.get('cat',0))
        if cat:
            cat_obj = Category.objects.get(pk=cat)
            places = places.filter(category__in=cat_obj.get_descendants(include_self=True))
    except:
        pass

    # Accessibility
    ac_form_set = []
    for v,k in ACCESS_AREAS:
        locals()[k] = request.GET.get(k,'')
        optline = []
        for ka,ube in ACCESS_CHOICES:
            if locals()[k] and locals()[k]==ka:
                optline.append((ka,ube,1))
                if ka=='a':
                    places = places.filter(**{'access__%s' % str(k):'a'})
                elif ka=='p':
                    places = places.filter(**{'access__%s__in' % str(k):['a','p']}
                    )
            else:
                optline.append((ka,ube,0))
        ac_form_set.append((k,v,optline))

    pagenumber = request.GET.get('page','1')
    if int(pagenumber)<1:
        pagenumber = 1

    results_number = len(places)

    # data for advanced form
    all_locations = []
    top_locs = Location.objects.filter(level=1).order_by('name')
    for prov in top_locs:
        locs = Location.objects.filter(parent=prov).order_by('name')
        all_locations.append((prov,locs))
    all_cats = Category.objects.filter(level=0)


    access_areas = ACCESS_AREAS
    access_choices = ACCESS_CHOICES

    pages = Paginator(places,10)
    thispage = pages.page(int(pagenumber))
    pins = thispage.object_list


    prev_pars = request.GET.copy()
    next_pars = request.GET.copy()
    if pagenumber == '1':
        prev_pars.update({'page':'1'})
    else:
        prev_pars.update({'page':thispage.previous_page_number()})
    try:
        next_pars.update({'page':thispage.next_page_number()})
    except:
        next_pars.update({'page':'1'})
    prev_url = "/filter/?%s" % "&".join(["%s=%s" % (k,v) for k,v in prev_pars.items()])
    next_url = "/filter/?%s" % "&".join(["%s=%s" % (k,v) for k,v in next_pars.items()])

    return render_to_response('search.html', locals(), context_instance=RequestContext(request))

def search(request):
    """ """
    hidesearch = True
    action = 'search'

    q = request.GET.get('q','')
    locations = Location.objects.filter(name__search=q)
    all_items = [loc for loc in locations]

    # q
    if q:
        places = Place.objects.filter(name__search=q, is_public=True)
    else:
        places = []

    pagenumber = request.GET.get('page','1')
    if int(pagenumber)<1:
        pagenumber = 1

    all_items.extend(places)
    results_number = len(all_items)

    # data for advanced form

    pages = Paginator(all_items,10)
    thispage = pages.page(int(pagenumber))


    pins = thispage.object_list

    prev_pars = request.GET.copy()
    next_pars = request.GET.copy()
    if pagenumber == '1':
        prev_pars.update({'page':'1'})
    else:
        prev_pars.update({'page':thispage.previous_page_number()})
    try:
        next_pars.update({'page':thispage.next_page_number()})
    except:
        next_pars.update({'page':'1'})
    prev_url = "/search/?%s" % "&".join(["%s=%s" % (k,v) for k,v in prev_pars.items()])
    next_url = "/search/?%s" % "&".join(["%s=%s" % (k,v) for k,v in next_pars.items()])

    return render_to_response('search.html', locals(), context_instance=RequestContext(request))

def set_language(request):
    next = request.REQUEST.get('next', None)
    if not next:
        next = request.META.get('HTTP_REFERER', None)
    if not next:
        next = '/'
    response = redirect(next)
    if request.method == 'GET':
        lang_code = request.GET.get('language', None)
        print lang_code
        if lang_code:
            if hasattr(request, 'session'):
                request.session['django_language'] = lang_code
            else:
                response.set_cookie(settings.LANGUAGE_COOKIE_NAME, lang_code)
            translation.activate(lang_code)
    return response

def useroptions(request):
    return render_to_response('useroptions.html', locals(), context_instance=RequestContext(request))

def gsearch(request):
    q = request.GET.get('q','')
    hidesearch = True
    action = 'search'
    return render_to_response('gsearch.html', locals(), context_instance=RequestContext(request))


from django import forms
from models import *
from django.utils.translation import ugettext_lazy as _

class CommentForm(forms.Form):
    """ """
    body = forms.CharField(label='',widget=forms.Textarea)
    photo  = forms.ImageField(label=_('Image'),help_text=_('Accepted formats: jpg, png, gif.'),required=False)

    def clean_body(self):
        """ """
        body = self.cleaned_data['body'].strip()
        if not body:
            raise forms.ValidationError(_('Void messages not accepted. Please, type some text explaining!'))
        return self.cleaned_data['body']
    
    def clean_photo(self):
        """ """
        photo = self.cleaned_data['photo']
        if not photo:
            return None


        name = photo.name
        try:
            name.encode('ascii')
        except:
            raise forms.ValidationError(_(u'The name of the file (%s) has an non standard character and cannot be processed. Please rename the image before uploading!') % name)            

        if len(name)>90:
            raise forms.ValidationError(_(u'The name of the file (%s) is too long. Please rename the image before uploading!') % name)            
        

        format = name.split('.')[-1]
        if format.lower().strip() not in (u'jpg',u'png',u'gif'):
            raise forms.ValidationError(_(u'The format of the image is not valid. Please upload an image in an accepted format!'))        
      
        return photo

    class Meta:
         model=Comment



from time import time
from datetime import datetime
import string

def time_slug():
    """ """
    return int(time())
    
def time_slug_long():
    """ """
    return int(time()*1000)

def time_slug_string():
    """ """
    return str(time_slug_long())

def date_from_timeslug(t):
    """ """    
    return datetime.fromtimestamp(float(t)) 


#* - encoding: utf-8 -*
import os
import codecs
from arartekomaps.locations.models import Location

# Cities uploader based on csv herriak.csv
def get_cities():
    loc_file = codecs.open('src/arartekomaps/arartekomaps/locations/herriak.csv','r','utf-8')
    locs = {}
    for line in loc_file.readlines():
        a,b = line.strip().split(',')
        prov,city = a.strip(),b.strip()
        if locs.has_key(prov):
            locs[prov].append(city)
        else:
            locs[prov]=[city]
    
    euskadi=Location(name=u"Euskadi")
    euskadi.save()
    for prob in locs.keys():
        myprob=Location(name=prob,parent=euskadi)
        myprob.save()
        print prob
        for city in locs[prob]:
            mycity = Location(name=city,parent=myprob)
            mycity.save()
            print city



# Django settings for arartekomaps project.
#!/usr/bin/python
# -*- coding: utf-8 -*-

import os

DEBUG = False
TEMPLATE_DEBUG = DEBUG

DEFAULT_FROM_EMAIL = ''
EMAIL_NOTIFICATION = ''

ADMINS = (
    ('Admin', 'admin@your_email.com'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql', # Add 'postgresql_psycopg2', 'pos$
        'NAME': '',                      # Or path to database file$
        'USER': '',                      # Not used with sqlite3.
        'PASSWORD': '',                  # Not used with sqlite3.
        'HOST': '',                      # Set to empty string for localhost. N$
        'PORT': '',                      # Set to empty string for default. Not$

    }
}

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = 'Europe/Madrid'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'es'

SITE_ID = 2

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale
USE_L10N = False

USE_THOUSAND_SEPARATOR = True
NUMBER_GROUPING = 3
THOUSAND_SEPARATOR = '.'

# This is defined here as a do-nothing function because we can't import
# django.utils.translation -- that module depends on the settings.
gettext_noop = lambda s: s

PAGE_LANGUAGES = (
  ('es', gettext_noop('Espanol')),
  ('eu', gettext_noop('Euskara')),
  ('en', gettext_noop('English')),
)

LANGUAGES = list(PAGE_LANGUAGES)

TRANSMETA_LANGUAGES = LANGUAGES


# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = '/home/csmant/django/ararteko/media/'

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = '/media/'

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = '/home/csmant/django/ararteko/static/'

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# URL prefix for admin static files -- CSS, JavaScript and images.
# Make sure to use a trailing slash.
# Examples: "http://foo.com/static/admin/", "/static/admin/".
ADMIN_MEDIA_PREFIX = '/static/admin/'

# Additional locations of static files
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.

)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'django.contrib.staticfiles.finders.DefaultStorageFinder',
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = '8k^83&=bw79j8@5&str!h!-s1fvg@c&33k#e(7t#bv5ocw^ufm'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
    # 'django.template.loaders.eggs.Loader',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'pagination.middleware.PaginationMiddleware',
)

ROOT_URLCONF = 'arartekomaps.urls'


BASE_DIR = os.path.dirname(os.path.abspath(__file__))

TEMPLATE_DIRS = (
    '%s/templates' % BASE_DIR,

)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.contrib.auth.context_processors.auth',
    'django.core.context_processors.i18n',
    'django.core.context_processors.debug',
    'django.core.context_processors.media',
    'django.core.context_processors.static',
    'django.core.context_processors.request',
    'django.contrib.messages.context_processors.messages'
)


INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
    'django.contrib.comments',
    'pagination',
    'social_auth',
    'registration',
    'cssocialuser',
    'arartekomaps',
    'arartekomaps.arartekouser',
    'arartekomaps.places',
    'arartekomaps.locations',
    'arartekomaps.categories',
    'arartekomaps.mycomment',
    'photologue',
    'pages',
    'gunicorn',
    'piston',
    'modeltranslation',
)

# SMTP CONFIG
EMAIL_HOST = ''
EMAIL_HOST_USER = ''
EMAIL_HOST_PASSWORD = ''
DEFAULT_FROM_EMAIL = ''

HOST = ''

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'file': {
            'level': 'ERROR',
            'class': 'logging.FileHandler',
            'filename': '/home/csmant/django/ararteko/logs/arartekomaps_error.log',
        },
    },
    'loggers': {
        'django.request': {
            'handlers': ['file'],
            'level': 'ERROR',
            'propagate': True,
        },
    },
}

AUTHENTICATION_BACKENDS = (
    'social_auth.backends.twitter.TwitterBackend',
    'social_auth.backends.facebook.FacebookBackend',
    # 'social_auth.backends.google.GoogleOAuthBackend',
    # 'social_auth.backends.google.GoogleOAuth2Backend',
    # 'social_auth.backends.google.GoogleBackend',
    # 'social_auth.backends.yahoo.YahooBackend',
    # 'social_auth.backends.contrib.linkedin.LinkedinBackend',
    'social_auth.backends.OpenIDBackend',
    # 'social_auth.backends.contrib.livejournal.LiveJournalBackend',
    'django.contrib.auth.backends.ModelBackend',
)

SOCIAL_AUTH_PIPELINE = (
    'social_auth.backends.pipeline.social.social_auth_user',
    'social_auth.backends.pipeline.associate.associate_by_email',
    'social_auth.backends.pipeline.user.get_username',
    'social_auth.backends.pipeline.user.create_user',
    'social_auth.backends.pipeline.social.associate_user',
    'social_auth.backends.pipeline.user.update_user_details',
    'social_auth.backends.pipeline.social.load_extra_data',
    #'cssocialuser.pipeline.extra_values.twitter_extra_values',
    #'cssocialuser.pipeline.extra_values.facebook_extra_values',
    #'cssocialuser.pipeline.extra_values.openid_extra_values',
)

# Login
LOGIN_REDIRECT_URL = '/'
LOGIN_URL = '/u/'
LOGOUT_URL = '/u/logout'
PASSWORD_RESET_TIMEOUT_DAYS = 365

#AUTH_PROFILE_MODULE = 'arartekouser.ArartekoUser'
AUTH_USER_MODEL = 'arartekouser.ArartekoUser'

# Dajngo-registration settings
ACCOUNT_ACTIVATION_DAYS = 5

# Twitter API
TWITTER_CONSUMER_KEY = ''
TWITTER_CONSUMER_SECRET = ''
REQUEST_TOKEN = ''
ACCESS_TOKEN = ''
AUTHORIZE_URL = ''

# Facebook API

FACEBOOK_APP_ID = ''
FACEBOOK_API_KEY = ''
FACEBOOK_API_SECRET = ''

PAGE_DEFAULT_TEMPLATE = 'pages/index.html'

MODELTRANSLATION_DEFAULT_LANGUAGE = 'es'
MODELTRANSLATION_FALLBACK_LANGUAGES = ('es', 'eu')

IMPORT_FILES_FOLDER = '/var/csmant/ararimport'


SECRET_KEY = 'vw=d$ccwccb&m=wf2^cz*($bv_x+i9rxmd+%jkbmsa3^#cgv*r'
ALLOWED_HOSTS = ['www.mapak.ararteko.net','mapak.ararteko.net','127.0.0.1','localhost']

USE_X_FORWARDED_HOST = True

try:
    from server_settings import *
except:
    pass

try:
    from local_settings import *
except:
    pass



from modeltranslation.translator import translator, TranslationOptions
from arartekomaps.places.models import Place

class PlaceTranslationOptions(TranslationOptions):
    fields = ('description','url_name','url','adescription')

translator.register(Place, PlaceTranslationOptions)



from django.core.management.base import BaseCommand
from arartekomaps.places.models import Place


class Command(BaseCommand):
    args = ''
    help = 'Download CSV with latlon'   
    
    def handle(self, *args, **options):
        places = Place.objects.filter(source='ejgv_biblio')
        for place in places:
            print "%s\t%s\t%s" % (place.source_id, place.lat, place.lon)


from django.contrib import admin
from arartekomaps.places.models import Place, Access, Biblio, Bibtopic, Bibservice, MPhoto
from arartekomaps.categories.models import Category
from django import forms
from django.template.loader import render_to_string
from arartekomaps.mycomment.models import Comment
from django.http import HttpResponse
from django.template import loader, Context

class BiblioInline(admin.TabularInline):
    model = Biblio
    extra = 1
    inlines = [ Bibtopic,Bibservice]

class BibtopicInline(admin.TabularInline):
    model = Bibtopic
    extra = 1

class BibserviceInline(admin.TabularInline):
    model = Bibservice
    extra = 1

class mapWidgetP(forms.widgets.Input):
    """ """
    input_type = None
    def render(self, name, value, attrs=None):
        return render_to_string('mapwidgetp.html', locals())

# class PlaceAdminForm(forms.ModelForm):
#     map = forms.CharField(widget=mapWidgetP(), required=False)
#     class Meta:
#         model = Place

def export_excel(modeladmin, request, queryset):
    response = HttpResponse(mimetype='text/csv')
    response['Content-Disposition'] = 'attachment; filename=map_export.csv'
    places = queryset
    t = loader.get_template('csv_export.txt')
    c = Context({
        'places': places,
    })
    response.write(t.render(c))
    return response
export_excel.short_description = 'Exportar a Excel'

def export_excel_comments(modeladmin, request, queryset):
    response = HttpResponse(mimetype='text/csv')
    response['Content-Disposition'] = 'attachment; filename=map_export_comments.csv'
    places = []
    for place in queryset:
        coms = Comment.objects.filter(object_pk = place.id)
        if len(coms)>0:
            places.append(place)
    t = loader.get_template('csv_export_comments.txt')
    c = Context({
        'places': places,
    })
    response.write(t.render(c))
    return response
export_excel_comments.short_description = 'Exportar comentarios'

class PlaceAdmin(admin.ModelAdmin):
    #form = PlaceAdminForm
    list_display = ('name','city','category','lat','lon','source','author')
    readonly_fields = ()
    search_fields = ('name',)
    inlines = [BiblioInline]
    list_filter = ('category','aphysic',
        'avisual','aaudio',
        'aintelec','aorganic',
        'source', 'city',)
    exclude = ('description','adescription')
    actions = [export_excel,export_excel_comments]

admin.site.register(Place, PlaceAdmin)

class CategoryAdmin(admin.ModelAdmin):
    list_display = ('name','slug')
    readonly_fields = ()
    search_fields = ('name',)
admin.site.register(Category, CategoryAdmin)

class BibtopicAdmin(admin.ModelAdmin):
    list_display = ('name',)
    readonly_fields = ()
    search_fields = ('name',)
admin.site.register(Bibtopic, BibtopicAdmin)

class BibserviceAdmin(admin.ModelAdmin):
    list_display = ('name',)
    readonly_fields = ()
    search_fields = ('name',)
admin.site.register(Bibservice, BibserviceAdmin)

class MPhotoAdmin(admin.ModelAdmin):
    search_fields = ['name']
admin.site.register(MPhoto,MPhotoAdmin)






from piston.handler import AnonymousBaseHandler, BaseHandler
from django.conf import settings
import json
import ast
from arartekomaps.locations.models import Location
from arartekomaps.categories.models import Category
from arartekomaps.places.models import Place, MPhoto
try:
    from django.contrib.auth import get_user_model
    User = settings.AUTH_USER_MODEL
except ImportError:
    from django.contrib.auth.models import User
from arartekomaps.mycomment.models import Comment
from django.contrib.auth import authenticate, login
from django.contrib.sites.models import Site
from django.contrib.auth.tokens import default_token_generator
from django.db import IntegrityError, transaction
from smtplib import SMTPException
from registration.models import RegistrationProfile
from cssocialuser.models import CSSocialUser

from django.utils import translation
from django.utils.translation import ugettext_lazy as _

from datetime import datetime
from arartekomaps.utils.load_images import handle_photo_file
from django.core.files.base import ContentFile

from social_auth.backends.pipeline.social import associate_user
from social_auth.backends.facebook import FacebookBackend
from social_auth.backends.twitter import TwitterBackend
from social_auth.models import UserSocialAuth
from social_auth.backends import get_backend
from django.utils import translation
import logging
import base64, urllib
from math import radians, cos, sin, asin, sqrt, degrees

logger = logging.getLogger(__name__)

ACCESS_KEYS = ("a","p")

SOCIAL_ORIGIN = {"1": "facebook", "2": "twitter"}
SOCIAL_BACKEND = {"1": FacebookBackend, "2": TwitterBackend}

def haversine(lon1, lat1, lon2, lat2):
    """
    Calculate the great circle distance between two points
    on the earth (specified in decimal degrees)
    """
    # convert decimal degrees to radians
    lon1, lat1, lon2, lat2 = map(radians, [lon1, lat1, lon2, lat2])
    # haversine formula
    dlon = lon2 - lon1
    dlat = lat2 - lat1
    a = sin(dlat/2)**2 + cos(lat1) * cos(lat2) * sin(dlon/2)**2
    c = 2 * asin(sqrt(a))
    km = 6371 * c
    return km

def get_gps_box(lat, lon):
    R = float(6371)
    radius = float(5)
    maxLon = lon - degrees(radius/R/cos(radians(lat)))
    minLon = lon + degrees(radius/R/cos(radians(lat)))
    maxLat = lat + degrees(radius/R)
    minLat = lat - degrees(radius/R)
    return maxLat, minLat, maxLon, minLon


class LocationsHandler(AnonymousBaseHandler):
    allowed_methods = ('GET',)
    fields = ('name', 'slug')
    model = Location

    def read(self, request):
        lang = request.GET.get("lang","eu")
        translation.activate(lang)
        try:
            locations = Location.objects.filter(level=2).order_by('name')
            json_loc = []
            for loc in locations:
                h = {'name': loc.name, 'slug': loc.slug}
                json_loc.append(h)
            return {'lang': lang, 'action': 'get_cities', 'result': 'success', 'values': json_loc}
        except:
            logger.error("Couldn't get location information")
            return {'lang': lang, 'action': 'get_cities', 'result': 'failed', 'value': 'generic_error', 'msg': translation.ugettext('Ezin izan da kokapen informazioa eskuratu')}


class CategoriesHandler(AnonymousBaseHandler):
    allowed_methods = ('GET',)
    model = Category

    def read(self, request):
        lang = request.GET.get("lang","eu")
        translation.activate(lang)
        try:
            categories = Category.objects.filter(parent=None).order_by('name')
            json_loc = []
            name = ''
            for cat in categories:
                if lang == 'eu':
                    name = cat.name_eu
                else:
                    name = cat.name_es
                h = {
                    'name': name,
                    'slug': cat.slug,
                    'icon': cat.icon()+'.png',
                }
                json_loc.append(h)
            return {'lang': lang, 'action': 'get_categories', 'result': 'success', 'values': json_loc}
        except:
            logger.error("Couldn't get categories")
            return {'lang': lang, 'action': 'get_categories', 'result': 'failed', 'value': 'generic_error', 'msg': translation.ugettext('Ezin dira kategoriak eskuratu')}

class PlaceHandler(AnonymousBaseHandler):
    allowed_methods = ('GET',)
    model = Place

    def read(self, request):
        slug = request.GET.get("slug","")
        lang = request.GET.get("lang","eu")
        translation.activate(lang)
        try:
            place = Place.objects.get(slug=slug)
            if MPhoto.objects.filter(place=place, def_img=True).exists():
                image = MPhoto.objects.filter(place=place, def_img=True)[0].get_place_API_url()
                #image = settings.HOST+image.get_place_API_url()
            else:
                image = None

            comments = Comment.objects.filter(parent=place)
            comment_list = []
            for comment in comments:
                if comment.photo:
                    c_img = settings.HOST+comment.photo.get_place_API_url()
                else:
                    c_img = ""
                if comment.author.get_profile().get_photo():
                    u_img = settings.HOST+comment.author.get_profile().get_photo().get_profile_API_url()
                else:
                    u_img = ""
                comment_list.append({
                    "name": comment.author.get_profile().get_fullname(),
                    "user_photo": u_img,
                    "public_date": comment.public_date.date(),
                    "text": comment.body,
                    "photo": c_img,
                })


            if place.tlf.find('-'):
                place.tlf = place.tlf.split('-')[0].strip()

            # if lang == 'eu':
            #     desc = place.description_eu
            # else:
            desc = u"%s\n\n%s\n\n%s" % (place.description_es, _('Accessibility'), place.access_data()['description'])

            if lang == 'eu':
                cat = place.category.name_eu
            else:
                cat = place.category.name_es

            json = {
                "name": place.name,
                "slug": place.slug,
                "category": {"name": cat, "slug": place.category.slug, "icon": place.category.icon()+'.png'},
                "description": desc,
                "address1": place.address1,
                "address2": place.address2,
                "postalcode": place.postalcode,
                "city": place.city.name,
                "locality": place.locality,
                "source": place.source,
                "source_id": place.source_id,
                "lat": place.lat,
                "lon": place.lon,
                "tlf": place.tlf,
                "fax": place.fax,
                "url": place.url,
                "email": place.email,
                "accesibility": place.access_dict_list(),
                "photo": image,
                "comments": comment_list
            }
            return {'lang': lang, 'action': 'get_place', 'result': 'success', 'values': json}
        except Exception, e:
            logger.error("ERROR: "+str(e))
            return {'lang': lang, 'action': 'get_place', 'result': 'failed', 'value': 'generic_error','msg': translation.ugettext('Sisteman errore bat gertatu da "lekua" eskuratzean: ')+str(e)}


class PlacesHandler(AnonymousBaseHandler):
    allowed_methods = ('GET',)
    model = Place

    def read(self, request):
        location = request.GET.get("location","")
        category = request.GET.get("category","")
        lang = request.GET.get("lang","eu")
        translation.activate(lang)
        aphysic = request.GET.get("aphysic","")
        avisual = request.GET.get("avisual","")
        aaudio = request.GET.get("aaudio","")
        aintelec = request.GET.get("aintelec","")
        aorganic = request.GET.get("aorganic","")
        lat = request.GET.get("lat","")
        lon = request.GET.get("lon","")

        args = {}
        json_list = []
        try:
            if location:
                loc = Location.objects.get(slug=location)
                if not loc.lon or not loc.lat:
                    return {'lang': lang, 'action': 'get_places', 'result': 'failed', 'value': 'location_not_geolocalized', 'msg': translation.ugettext('Lekua ez dago geo-kokatuta. Jarri kontaktuan guneko administratzaileekin.')}
                lon1 = float(loc.lon)
                lat1 = float(loc.lat)
            elif lat and lon:
                lat1 = float(lat)
                lon1 = float(lon)
            else:
                return {'lang': lang, 'action': 'get_places', 'result': 'failed', 'value': 'not_lat_lon', 'msg': translation.ugettext('Latitude eta longitudeak ezin izan dira eskuratu.')}

            maxLat,minLat,maxLon,minLon = get_gps_box(lat1,lon1)
            args['lat__range'] = (str(minLat),str(maxLat))
            args['lon__range'] = (str(maxLon),str(minLon))

            if category:
                cat = Category.objects.get(slug=category)
                categories = []
                for csl in cat.get_children():
                    categories.append(csl.slug)
                categories.append(cat.slug)
                args['category__slug__in'] = categories

            if aphysic in ACCESS_KEYS:
                if aphysic == "a":
                    args['access__aphysic'] = aphysic
                elif aphysic == "p":
                    args['access__aphysic__in'] = ACCESS_KEYS
            if avisual in ACCESS_KEYS:
                if avisual == "a":
                    args['access__avisual'] = avisual
                elif avisual == "p":
                    args['access__avisual__in'] = ACCESS_KEYS
            if aaudio in ACCESS_KEYS:
                if aaudio == "a":
                    args['access__aaudio'] = aaudio
                elif aaudio == "p":
                    args['access__aaudio__in'] = ACCESS_KEYS
            if aintelec in ACCESS_KEYS:
                if aintelec == "a":
                    args['access__aintelec'] = aintelec
                elif aintelec == "p":
                    args['access__aintelec__in'] = ACCESS_KEYS
            if aorganic in ACCESS_KEYS:
                if aorganic == "a":
                    args['access__aorganic'] = aphysic
                elif aorganic == "p":
                    args['access__aorganic__in'] = ACCESS_KEYS

            places = Place.objects.filter(**args)

            for place in places:
                # if lang == 'eu':
                #     desc = place.description_eu
                # else:


                desc = u"%s\n\n%s\n\n%s" % (place.description_es, _('Accessibility'), place.access_data()['description'])

                if lang == 'eu':
                    cat = place.category.name_eu
                else:
                    cat = place.category.name_es

                json = {
                    "name": place.name,
                    "slug": place.slug,
                    "category": {"name": cat, "slug": place.category.slug, "icon": place.category.icon()+'.png'},
                    "description": desc,
                    "address1": place.address1,
                    "address2": place.address2,
                    "postalcode": place.postalcode,
                    "city": place.city.name,
                    "locality": place.locality,
                    "lat": place.lat,
                    "lon": place.lon,
                    "distance": haversine(place.lon, place.lat, lon1, lat1),
                    "accesibility": place.access_dict_list(),
                    "comment_count": place.get_comments_count(),
                }
                json_list.append(json)
            json_list = sorted(json_list, key=lambda k: k['distance'])
            if not json_list:
                return {'lang': lang, 'action': 'get_filtered_places', 'result': 'failed', 'value': 'empty', 'msg': translation.ugettext('Egin duzun bilaketarako ez dugu ezer aurkitu.')}
            return {'lang': lang, 'action': 'get_filtered_places', 'result': 'success', 'values': json_list[:10]}
        except Exception, e:
            logger.error("ERROR: "+str(e))
            return {'lang': lang, 'action': 'get_filtered_places', 'result': 'failed', 'value': 'generic_error', 'msg': translation.ugettext('Sisteman errore bat gertatu da "lekuak" eskuratzean: ')+str(e)}

class UserHandler(AnonymousBaseHandler):
    allowed_methods = ('POST',)
    model = User

    def create(self, request):

        username = request.POST.get("username","")
        email = request.POST.get("email","")
        passw = request.POST.get("pass","")
        origin = request.POST.get("origin","")
        lang = request.GET.get("lang","eu")
        translation.activate(lang)

        full_name = request.POST.get("full_name","")
        biography = request.POST.get("biography","")
        oauth_token_secret = request.POST.get("secret","")
        oauth_token = request.POST.get("token","")
        expires = request.POST.get("expires","")
        social_id = request.POST.get("id","")
        photo = request.POST.get("photo","")


        if origin == "":
            if not username:
                logger.error("ERROR: There is not enough data")
                return {'action': 'login_or_register', 'result': 'failed', 'value': 'not_enough_data', 'msg': translation.ugettext('Datu gehiago behar ditugu. Erabiltzaile izena, eposta edo pasahitza falta zaigu.')}
            elif passw and email:
                try:
                    site = Site.objects.get(id=settings.SITE_ID)
                    if not re.match(r'[\w-]+', username):
                        return {'action': 'login_or_register', 'result': 'failed', 'value': 'invalid_form_values', 'msg': translation.ugettext('Erabiltzaile izenak hizki, zenbaki eta @/./+/-/_ karaktereak bakarrik izan ditzazke.')}
                    RegistrationProfile.objects.create_inactive_user(username, email, passw, site)
                    return {'action': 'login_or_register', 'result': 'success'}
                except IntegrityError, e:
                    logger.error("ERROR: "+str(e))
                    return {'action': 'login_or_register', 'result': 'failed', 'value': 'integrity_error', 'msg': translation.ugettext('Erabiltzaile izen hau lehendik ere existitzen da. Mesedez, erabili beste izen bat.')}
                except SMTPException, e:
                    logger.error("ERROR: "+str(e))
                    return {'action': 'login_or_register', 'result': 'failed', 'value': 'smtp_error', 'msg': translation.ugettext('Arazo bat egon da aktibazio eposta bidaltzean')}
                except Exception as e:
                    logger.error("ERROR: "+str(e))
                    return {'action': 'login_or_register', 'result': 'failed', 'value': 'unknown_error', 'msg': translation.ugettext('Erabiltzailea erregistratzean errore bat gertatu da')}
            elif passw and not email:
                user = authenticate(username=username, password=passw)
                if user is not None:
                    if user.is_active:
                        login(request, user)
                        token = default_token_generator.make_token(user)
                        # Redirect to a success page.
                        return {'action': 'login_or_register', 'result': 'success', 'value': token}
                    else:
                        # Return a 'disabled account' error message
                        logger.error("ERROR: User is not active")
                        return {'action': 'login_or_register', 'result': 'failed', 'value': 'user_not_active', 'msg': translation.ugettext('Erabiltzailea ez dago aktibatuta. Mesedez, begiratu zure epostara bidali dugun mezua eta jarraitu aktibazio pausoak.')}
                else:
                    # Return an 'invalid login' error message.
                    logger.error("ERROR: User is not authenticated")
                    return {'action': 'login_or_register', 'result': 'failed', 'value': 'user_is_not_authenticated', 'msg': translation.ugettext('Erabiltzailea edo pasahitz okerrak. Mesedez, saiatu berriro.')}
            else:
                logger.error("ERROR: Not enough data")
                return {'action': 'login_or_register', 'result': 'failed', 'value': 'not_enough_data', 'msg': translation.ugettext('Datu gehiago behar ditugu. Erabiltzaile izena, eposta edo pasahitza falta zaigu.')}
        elif origin in tuple(SOCIAL_ORIGIN.keys()):
            if origin == "1":
                access_token = u'{"access_token": "'+oauth_token+'", "expires": "'+expires+'", "id": '+social_id+'}'
            else:
                access_token = u'{"access_token": "oauth_token_secret='+oauth_token_secret+'&oauth_token='+oauth_token+'", "id": '+social_id+'}'
            if not User.objects.filter(username=username).exists():
                try:
                    user = User()
                    user.username = username
                    user.is_active = True
                    user.save()
                    usa, created = UserSocialAuth.objects.get_or_create(user=user, provider = SOCIAL_ORIGIN[origin], uid=int(social_id))
                    usa.extra_data = access_token
                    usa.save()
                except IntegrityError, e:
                    logger.error("ERROR:"+str(e))
                    return {'action': 'login_or_register', 'result': 'failed', 'value': 'integrity_error', 'msg': translation.ugettext('Erabiltzaile izen hau lehendik ere existitzen da. Mesedez, erabili beste izen bat.')}

            access_token = ast.literal_eval(access_token)
            try:
                backend = get_backend(SOCIAL_ORIGIN[origin], request, request.path)
                user = backend.do_auth(access_token['access_token'])
            except Exception as e:
                logger.error("ERROR: "+str(e))
                return {'action': 'login_or_register', 'result': 'failed', 'value': 'auth_error', 'msg': translation.ugettext('Sare sozialetako autentikazioak huts egin du: ')+str(e)}
            if user and user.is_active:
                login(request, user)
                token = default_token_generator.make_token(user)
                # Redirect to a success page.
                return {'action': 'login_or_register', 'result': 'success', 'value': token, 'username': user.username}
            else:
                # Return a 'disabled account' error message
                logger.error("ERROR: User is not active!")
                return {'action': 'login_or_register', 'result': 'failed', 'value': 'user_not_active', 'msg': translation.ugettext('Erabiltzailea ez dago aktibatuta. Mesedez, begiratu zure epostara bidali dugun mezua eta jarraitu aktibazio pausoak.')}
        else:
            logger.error("ERROR: Wrong origin!")
            return {'action': 'login_or_register', 'result': 'failed', 'value': 'wrong_origin', 'msg': translation.ugettext('Jatorri ezezaguneko erabiltzailea. Jarri administratzaileekin harremanetan.')}

class CommentHandler(BaseHandler):
    allowed_methods = ('POST',)
    model = Comment

    def create(self, request):
        username = request.POST.get("username","")
        origin = request.POST.get("origin","")
        social_id = request.POST.get("id","")
        token = request.POST.get("token","")
        text = request.POST.get("text","")
        slug = request.POST.get("slug","")
        lang = request.GET.get("lang","eu")
        translation.activate(lang)

        f = open('post_saiakerak.txt','w')
        try:
            if origin in tuple(SOCIAL_ORIGIN.keys()):
                if origin == "1":
                    profile = CSSocialUser.objects.get(facebook_id=username)
                    user = profile.user
                else:
                    profile = CSSocialUser.objects.get(twitter_id=username)
                    user = profile.user
            else:
                user = User.objects.get(username=username)
                f.write('[OK] Username: '+username+' | Text: '+text+' | Slug: '+slug+' | Token: '+token+'\n')
        except:
            logger.error("ERROR: Invalid username")
            f.write('[ERROR] Username: '+username+' | Text: '+text+' | Slug: '+slug+' | Token: '+token+'\n')
            return {'action': 'post_comment', 'result': 'failed', 'value': 'invalid_username', 'msg': translation.ugettext('Erabiltzaile hori ez da sisteman existitzen. Jarri administratzailearekin kontaktuan.')}

        f.close()
        if default_token_generator.check_token(user,token):
            try:
                place = Place.objects.get(slug=slug)

                if text:
                    comment = Comment()
                    comment.author = user
                    comment.is_public = True
                    comment.public_date = datetime.today()
                    comment.parent = place
                    comment.body = text
                    comment.ip_address = request.META.get("REMOTE_ADDR", None)
                    if 'photo' in request.FILES:
                        try:
                            photo = handle_photo_file(request.FILES['photo'], user.username)
                        except Exception, e:
                            return {'action': 'post_comment', 'result': 'failed', 'value': 'decoding_error', 'msg': translation.ugettext('Irudiaren formatua ez da egokia. JPG formatuan bidali mesedez.')+str(e)}
                        comment.photo = photo
                    comment.save()
                    return {'action': 'post_comment', 'result': 'success'}
                else:
                    return {'action': 'post_comment', 'result': 'failed', 'value': 'text_not_found', 'msg': translation.ugettext('Iruzkinak ez dauka testurik. Testua beharrezkoa da.')}

            except Exception as e:
                logger.error("ERROR: "+str(e))
                return {'action': 'post_comment', 'result': 'failed', 'value': 'place_error', 'msg': translation.ugettext('Iruzkina utzi nahi den "lekua" aurkitzean errorea: ')+str(e)}
        else:
            logger.error("ERROR: Invalid token")
            return {'action': 'post_comment', 'result': 'failed', 'value': 'invalid_token', 'msg': translation.ugettext('Erabiltzaile saioa iraungi da. Berriz sartu zure erabiltzaile eta pasahitzarekin.')}

class GetCommentHandler(AnonymousBaseHandler):
    allowed_methods = ('GET',)
    model = Comment

    def read(self, request):
        slug = request.GET.get("slug","")
        lang = request.GET.get("lang","eu")
        translation.activate(lang)
        try:
            place = Place.objects.get(slug=slug)
            comments = Comment.objects.filter(parent=place)
            comment_list = []
            for comment in comments:
                if comment.photo:
                    c_img = settings.HOST+comment.photo.get_place_API_url()
                else:
                    c_img = ""
                if comment.author.get_profile().get_photo():
                    u_img = settings.HOST+comment.author.get_profile().get_photo().get_profile_API_url()
                else:
                    u_img = ""
                comment_list.append({
                    "name": comment.author.get_profile().get_fullname(),
                    "user_photo": u_img,
                    "public_date": comment.public_date.date(),
                    "text": comment.body,
                    "photo": c_img,
                })
            return {'lang': lang, 'action': 'get_comments', 'result': 'success', 'values': comment_list}
        except Exception, e:
            logger.error("ERROR:"+str(e))
            return {'lang': lang, 'action': 'get_comments', 'result': 'failed', 'value': 'comments_error', 'msg': translation.ugettext('Iruzkinak eskuratzean errore bat gertatu da: ')+str(e)}


from django import forms

class LocationWidget(forms.widgets.Widget):
    def __init__(self, *args, **kw):
        super(LocationWidget, self).__init__(*args, **kw)
        self.inner_widget = forms.widgets.HiddenInput()

    def render(self, name, value, *args, **kwargs):
        js = '''
        </script>
        <script type="text/javascript">
            //<![CDATA[
            var %(name)s_marker ;
            $(document).ready(function () {
                if (GBrowserIsCompatible()) {
                    var map = new GMap2(document.getElementById("map_%(name)s"));
                    map.setCenter(new GLatLng(4.735543142197098,-74.0822696685791), 13);
                    %(name)s_marker = new GMarker(new GLatLng(4.735543142197098,-74.0822696685791), {draggable: true});
                    map.addOverlay(%(name)s_marker);
                    map.addControl(new GLargeMapControl());
                    $('#%(name)s_id')[0].value = %(name)s_marker.getLatLng().lat() + "," + %(name)s_marker.getLatLng().lng();
                    GEvent.addListener(%(name)s_marker, "dragend", function() {
                        var point = %(name)s_marker.getLatLng();
                        $('#%(name)s_id')[0].value = point.lat() + "," + point.lng();
                    });
                }});
            $(document).unload(function () {GUnload()});
            //]]>
        </script>
        ''' % dict(name=name)
        html = self.inner_widget.render("%s" % name, None, dict(id='%s_id' % name))
        html += "<div id=\"map_%s\" style=\"width: 500px; height: 500px\"></div>" % name
        return mark_safe(js+html)


class LocationField(forms.Field):
    widget = LocationWidget

    def clean(self, value):
        a, b = value.split(',')
        lat, lng = float(a), float(b)
        return (lat, lng)


from django.db import models

class OldUser(models.Model):
    username = models.CharField(max_length=230)
    first_name = models.CharField(max_length=230)
    last_name = models.CharField(max_length=230)
    email = models.CharField(max_length=230)
    password = models.CharField(max_length=230)
    is_staff = models.BooleanField(default=False)
    is_active = models.BooleanField(default=False)
    is_superuser = models.BooleanField(default=False)
    last_login = models.DateTimeField()
    date_joined = models.DateTimeField()

    class Meta:
        db_table ='auth_user'


from django.conf.urls.defaults import patterns, include, url
from django.views.generic import RedirectView
from django.contrib import admin
admin.autodiscover()

urlpatterns = patterns('',
    
    url(r'^$', RedirectView.as_view(url='/')),
    url(r'^(?P<state>[^/]+)/$', 'arartekomaps.locations.views.listing', name='listing'),
    url(r'^(?P<state>[^/]+)/(?P<city>[^/]+)/$', 'arartekomaps.locations.views.location', name='location'),
    url(r'^(?P<state>[^/]+)/(?P<city>[^/]+)/(?P<maincat>[^/]+)/$', 'arartekomaps.locations.views.location', name='location'),    
    url(r'^(?P<state>[^/]+)/(?P<city>[^/]+)/(?P<maincat>[^/]+)/(?P<subcat>[^/]+)/$', 'arartekomaps.locations.views.location', name='location'),
 
    # Uncomment the admin/doc line below to enable admin documentation:
    #url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
   

)



from modeltranslation.translator import translator, TranslationOptions
from arartekomaps.places.models import Category

class CategoryTranslationOptions(TranslationOptions):
    fields = ('name',)

translator.register(Category, CategoryTranslationOptions)



from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from arartekomaps.arartekouser.models import ArartekoUser
from django.utils.translation import ugettext, ugettext_lazy as _
from django.contrib.auth.forms import AdminPasswordChangeForm,UserCreationForm, UserChangeForm
from django.contrib.auth.forms import ReadOnlyPasswordHashField
from django.contrib.auth.admin import UserAdmin
from django.forms import ModelForm
from django import forms
from django.forms.extras.widgets import SelectDateWidget


class MyUserChangeForm(UserChangeForm):
    class Meta(UserChangeForm.Meta):
        model = ArartekoUser

class MyUserCreationForm(ModelForm):
    """A form for creating new users. Includes all the required
    fields, plus a repeated password."""
    password1 = forms.CharField(label='Password', widget=forms.PasswordInput)
    password2 = forms.CharField(label='Password confirmation', widget=forms.PasswordInput)

    class Meta:
        model = ArartekoUser
        #fields = ('password1','password2','username' )

    def clean_password2(self):
        # Check that the two password entries match
        password1 = self.cleaned_data.get("password1")
        password2 = self.cleaned_data.get("password2")
        if password1 and password2 and password1 != password2:
            raise forms.ValidationError("Passwords don't match")
        return password2

    def save(self, commit=True):
        # Save the provided password in hashed format
        user = super(MyUserCreationForm, self).save(commit=False)
        user.set_password(self.cleaned_data["password1"])
        if commit:
            user.save()
        return user



class ArartekoUserAdmin(UserAdmin):

    form = MyUserChangeForm
    change_user_password_template = None
    add_form = MyUserCreationForm
    change_password_form = AdminPasswordChangeForm

    list_display = ('username','fullname','get_email','is_staff','is_active')
    list_display_links = ('fullname','username')
    search_fields = ['email','username','fullname']
    raw_id_fields = ('photo',)

    fieldsets = (
        (None, {'fields': ('username','email','password')}),

        ('Datuak',
        {'fields':('fullname','photo','bio')},),
        (_('Permissions'), {'fields': ('is_active','is_editor','is_staff','is_superuser',
                                       'groups', 'user_permissions','last_login'),
                            'classes': ['collapse',],}),

    )


    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('username', 'password1', 'password2')}
        ),
    )

    def get_email(self, obj):
        """ """
        return obj.email

    def get_form(self, request, obj=None, **kwargs):
        """
        Use special form during user creation
        """
        defaults = {}
        if obj is None:
            defaults['form'] = self.add_form
        defaults.update(kwargs)
        return super(ArartekoUserAdmin, self).get_form(request, obj, **defaults)


admin.site.register(ArartekoUser,ArartekoUserAdmin)


# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand
from arartekomaps.categories.models import Category
from arartekomaps.places.models import Place, Access, Biblio, Bibtopic, Bibservice, MPhoto
from arartekomaps.arartekouser.models import ArartekoUser as User
from arartekomaps.locations.models import Location
from arartekomaps.locations.utils import slugify
import xlrd, StringIO, urllib2
from arartekomaps.utils.load_images import loadUrlImage
from arartekomaps.settings import IMPORT_FILES_FOLDER

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload places from file (CSV)'
    ADICT = {'inaccesible':'n',
             'no_accesible':'n',
             'no accesible':'n',
             'sin datos': 's',
             'sin_datos': 's',
             '':'s',
             'practicable': 'p',
             'accesible': 'a'}
    
    RDICT = {'restaurante':'restaurant',
            'sidreria':'sidreria',
            'asador':'asador',
            'bodega-de-vino-rioja-alavesa':'bodega-rioja',
            'bodega-de-txakoli':'bodega-txakoli',
            'comida-rapida':'fast-food',
            'pasteleria-confiteria':'pasteleria'
            }
     
    def handle(self, *args, **options):
        saving = len(args)>1 and args[1] or 0
        line = len(args)>2 and int(args[2]) or 1
        filename = args[0]
        full_path = "%s/%s" % (IMPORT_FILES_FOLDER,filename)
        f = xlrd.open_workbook(full_path)
        sh = f.sheet_by_index(0)
        kont = 1
        ercnt =1
        
        CDICT = {'legutiano':'legutio',
                 'ribera-alta':'erriberagoitia', 
        }

        uloc = {}

        new_rest = 0

        for rownum in range(sh.nrows)[line:]:
            fields = sh.row_values(rownum)
            print '############################'
            print kont
            if len(fields)!=25:
                print 'Tenemos mas o menos de 25 campos'
                n = 1
                for field in fields:
                    print n, field
                    n = n+1
                break
            else:
                (titulo, slug, ent_origen, cod_origen, rcat, 
                direc1, direc2, cp, pob, loc, desc, lat, lon, tel, fax, url, 
                foto_x, foto_x_tit, foto_x_alt, itinerarios, 
                acc_fis, acc_vis, acc_aud, acc_int, 
                acc_org ) = fields[:25]


            translation = False
            ent_origen = 'ejgv-tur-rest'
            places = Place.objects.filter(source_id=cod_origen, source=ent_origen)
            if len(places)<1:
                places = Place.objects.filter(source_id=str(int(cod_origen)), source=ent_origen)
            if len(places)>0:
                place = places[0]
            if '_eu' in filename and place:
                place.description_eu = desc
                translation = True
            elif '_en' in filename and place:
                place.description_en = desc
                translation = True
            elif '_eu' in filename or '_en' in filename:
                translation = True

            if translation:
                place.save()
                continue
                
            #GET USER!!!!
            author = User.objects.get(username=ent_origen)

            location_slug = slugify(pob)

            if CDICT.has_key(location_slug):
                location_slug = CDICT[location_slug]           
            location = Location.objects.filter(slug__startswith=location_slug)
            if location:
                loc_obj = location[0]
            else:
                print ercnt,'WARNING: New place', titulo, cp, pob, kont
                uloc[pob]=uloc.get(pob,0)+1
                ercnt = ercnt+1
                break
     

            if len(places)>0:
                place = places[0]
                print 'EDIT:', slug, cod_origen
            else:
                place = Place()
                print slug
                place.slug = slugify(slug.split('/')[2],instance=place)
                print 'NEW:', slug, cod_origen

                if rcat: 
                    cat = slugify(rcat)
                    cat = self.RDICT.get(cat,cat)
                    rel_cat = Category.objects.filter(slug=cat)
                    if len(rel_cat)>0:
                        cat_obj = Category.objects.get(slug=cat)
                    else:
                        print 'WARNING: Missing cat:', cat
                        parentcat = Category.objects.get(slug='sleep')
                        cat_obj = Category(slug=cat,name=cat,name_es=cat,name_eu=cat,name_en=cat,parent=parentcat)
                        if saving:
                            cat_obj.save()
                else:
                    cat_obj = Category.objects.get(slug='sleep')

                place.category = cat_obj

                new_rest +=1
            
            place.name = titulo
            place.description_es = desc
            place.address1 = direc1
            place.address2 = ""
            if len(cp)<5:
                cp = "0%s" % cp
            place.postalcode = cp.strip()
            try:
                place.city = loc_obj
            except:
                pass
            place.locality = pob != loc and loc or ""
            place.description = desc
            place.source = ent_origen
            place.source_id = "%d" % int(cod_origen)
            if lat:
                place.lat = str(lat)
            if lon:
                place.lon = str(lon)

            #SET USER!!!!!
            place.author = author
            place.tlf = ''.join(tel[:30].split())
            place.fax = ''.join(fax[:15].split())
            place.url = url
            place.email = ''
            if saving:
                place.save()
            
            accesses = Access.objects.filter(place=place)
            if len(accesses)>0:
                access = accesses[0]
            else:
                access = Access()
                access.place = place
            access.aphysic = self.ADICT[acc_fis.lower().strip()]
            access.avisual = self.ADICT[acc_vis.lower().strip()]
            access.aaudio = self.ADICT[acc_aud.lower().strip()]
            access.aintelec = self.ADICT[acc_int.lower().strip()]
            access.aorganic = self.ADICT[acc_org.lower().strip()]
            
            if saving:
                access.save()




            #print foto_x
            t_place = place
            has_point = foto_x.split('/')[-1].find('.')
            if has_point>-1:
                if saving:
                    image = loadUrlImage(foto_x, t_place, foto_x_tit, 'jpg', )            
            kont += 1

        print "New restaurants: %d" % (new_rest)
        print uloc
        



from django.db import models
from django.conf import settings
try:
    from django.contrib.auth import get_user_model
    User = settings.AUTH_USER_MODEL
except ImportError:
    from django.contrib.auth.models import User
from photologue.models import Photo
from arartekomaps.places.models import Place
from arartekomaps.utils.slug import *
from django.db.models.signals import post_save
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from django.core.mail import send_mail

class Comment(models.Model):
    """ """

    slug = models.BigIntegerField(unique=True, db_index=True, editable=False)

    author = models.ForeignKey(settings.AUTH_USER_MODEL)

    parent = models.ForeignKey(Place, null=True, blank=True, related_name='parent')
    body = models.TextField(null=True, blank=True)
    photo = models.ForeignKey(Photo, null=True, blank=True)

    is_public = models.BooleanField(default=True, db_index=True)
    # ALTER TABLE `mycomment_comment` ADD `is_deleted` BOOLEAN NOT NULL DEFAULT FALSE AFTER `is_public` ;
    is_deleted = models.BooleanField(default=False, db_index=True)
    public_date = models.DateTimeField(db_index=True)

    ip_address = models.IPAddressField('IP address', blank=True, null=True)
    added = models.DateTimeField(auto_now_add=True)
    modified = models.DateTimeField(auto_now=True)


    def get_absolute_url(self):
        """ """
        return '%s#c%d' % (self.parent.get_absolute_url(), self.slug)

    def save(self, *args, **kwargs):
        """ """

        if not self.slug:
            self.slug = time_slug()

        super(Comment, self).save(*args, **kwargs)

    class Meta:
        ordering = ['-added']
        verbose_name = 'Comment'
        verbose_name_plural = 'Comments'


def send_comment_notification(sender, instance, created, **kwargs):
    if created:
        send_mail(_('[NEW COMMENT] '), _('New comment saved: ') + instance.body + '\n\n' + settings.HOST+'/admin/mycomment/comment/' + str(instance.id), settings.DEFAULT_FROM_EMAIL,
            [settings.EMAIL_NOTIFICATION], fail_silently=True)
    return True

post_save.connect(send_comment_notification, sender=Comment)




from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from arartekomaps.settings import STATIC_URL
from arartekomaps.locations.models import Location
from arartekomaps.places.models import Place, MPhoto
from arartekomaps.places.forms import PlaceForm
from django.contrib.auth.decorators import login_required
from django.http import HttpResponseRedirect
from datetime import datetime
from arartekomaps.utils.load_images import handle_photo_file
from arartekomaps.categories.models import Category
from arartekomaps.mycomment.forms import CommentForm
from arartekomaps.mycomment.models import Comment
from django.core.urlresolvers import reverse

def placeview(request, slug=''):
    """ """
    template_name='place'
    users = []
    place = get_object_or_404(Place, slug=slug)
    if MPhoto.objects.filter(place=place, def_img=True).exists():
        def_images = MPhoto.objects.filter(place=place, def_img=True)
    images = MPhoto.objects.filter(place=place,def_img=False).order_by('user')
    username = None
    imgs = []
    for i, image in enumerate(images):
        if not users:
            username = image.user
            imgs.append(image)
        elif username == image.user:
            imgs.append(image)
        else:
            users.append({'user': username, 'images': imgs})
            imgs = image
            username = image.user
        if i == len(images)-1:
            users.append({'user': username, 'images': imgs})

    if request.method == 'POST':
        kopia=request.POST.copy()
        kopia['author_id']=request.user.id
        kopia['is_public']=True
        form = CommentForm(kopia)
        if form.is_valid():
              comment = Comment()
              comment.author = request.user
              comment.is_public = True
              comment.public_date = datetime.today()
              comment.parent = place
              comment.body = form.cleaned_data['body']
              comment.ip_address = request.META.get("REMOTE_ADDR", None)
              if request.FILES.get('photo',''):
                 photo = handle_photo_file(request.FILES['photo'], request.user.username)
                 comment.photo= photo
              comment.save()
    form = CommentForm()
    comments = Comment.objects.filter(parent=place,is_public=True,is_deleted=False)

    return render_to_response('place.html', locals(), context_instance=RequestContext(request)
    )

@login_required
def locateme(request, slug=''):
    template_name='locateme'
    place = get_object_or_404(Place, slug=slug)
    if place.lat:
        df_lat, df_lon = place.lat, place.lon
    else:
        df_lat, df_lon = 43.21323021, -2.4114561080
    return render_to_response('locateme.html', locals(), context_instance=RequestContext(request)
    )

@login_required
def save_location(request):
    if request.method == 'POST': # If the form has been submitted...
        place_slug = request.REQUEST['place_slug']
        lat = request.REQUEST['lat']
        lon = request.REQUEST['lon']
        myPlace = get_object_or_404(Place, slug=place_slug)
        myPlace.lat=lat
        myPlace.lon=lon
        myPlace.save()
        return HttpResponseRedirect(myPlace.get_absolute_url()) # Redirect after POST
    else:
        place_slug = request.REQUEST['place_slug']
        if request.REQUEST.has_key('place_slug'):
            myBizi = get_object_or_404(Place, slug=place_slug)
            return HttpResponseRedirect(myPlace.get_absolute_url())
        else:
            return HttpResponseRedirect('/')

@login_required
def addPhoto(request, slug=''):
    template_name='addphoto'
    place = get_object_or_404(Place, slug=slug)
    if request.method == 'POST': # If the form has been submitted...
        if request.FILES.get('image',''):
            photo = MPhoto()
            photo.name = request.REQUEST['name']
            photo.image = request.FILES['image']
            photo.user= request.user
            photo.place = place
            photo.save()
        return HttpResponseRedirect(place.get_absolute_url()) # Redirect after POST
    else:
        return render_to_response('addphoto.html', locals(), context_instance=RequestContext(request)
        )

@login_required
def my_places(request):
    args = {}
    name =  request.GET.get("name","")
    category = Category.objects.filter(slug=request.GET.get("category",""))
    city = Location.objects.filter(slug=request.GET.get("city",""))
    if name:
        args['name'] = name
    if category:
        args['category'] = category
    if city:
        args['city'] = city
    args['author'] = request.user

    my_places = Place.objects.filter(**args)
    categories = Category.objects.filter(parent__isnull=False).order_by('name')
    cities = Location.objects.filter(level=2).order_by('name')
    return render_to_response('places/my_places.html', locals(), context_instance=RequestContext(request)
            )

@login_required
def delete_place(request, slug=None):
    if slug:
        place = get_object_or_404(Place, slug=slug)
        place.delete()
    return HttpResponseRedirect(reverse("edit_places"))

@login_required
def new_place(request):
    template_name='newplace'
    user = request.user
    if request.method == 'POST':
        posta=request.POST.copy()
        form = PlaceForm(posta)
        if form.is_valid():
            place = form.save(commit=False)
            place.lat = float(request.POST.get("lat","0"))
            place.lon = float(request.POST.get("lon","0"))
            place.author = user
            place.save()
            if request.FILES.get('photo',''):
                photo = MPhoto()
                photo.name = request.REQUEST['name']
                photo.image = request.FILES['photo']
                photo.user= user
                photo.def_img = True
                photo.place = place
                photo.save()
        else:
            return render_to_response('places/new_place.html', locals(), context_instance=RequestContext(request))
        return HttpResponseRedirect(reverse("edit_places"))
    else:
        form = PlaceForm()
        return render_to_response('places/new_place.html', locals(), context_instance=RequestContext(request))

@login_required
def edit_place(request, slug=None):
    template_name='editplace'
    user = request.user
    if request.method == 'POST':
        posta=request.POST.copy()
        place = get_object_or_404(Place, slug=slug)
        form = PlaceForm(posta, instance=place)
        if form.is_valid():
            place = form.save(commit=False)
            place.lat = float(request.POST.get("lat","0"))
            place.lon = float(request.POST.get("lon","0"))
            place.author = user
            place.save()
            if request.FILES.get('photo',''):
                photo = MPhoto()
                photo.name = request.REQUEST['name']
                photo.image = request.FILES['photo']
                photo.user= user
                photo.def_img = True
                photo.place = place
                photo.save()
            return HttpResponseRedirect(reverse("edit_places"))
        else:
            return render_to_response('places/edit_place.html', locals(), context_instance=RequestContext(request))
    else:
        place = get_object_or_404(Place, slug=slug)
        form = PlaceForm(instance=place)
        return render_to_response('places/edit_place.html', locals(), context_instance=RequestContext(request))


from arartekomaps.mycomment.models import Comment as MyComment
from django.contrib.comments import Comment
from django.contrib import admin

class CommentAdmin(admin.ModelAdmin):
    list_display = ('slug', 'author','public_date','parent','is_public','is_deleted')
    raw_id_fields = ('parent', 'author')   
    ordering = ('public_date',)
    search_fields = ['body','author']
    date_hierarchy = 'public_date'
    
admin.site.unregister(Comment)
admin.site.register(MyComment, CommentAdmin)  


from django.core.management.base import BaseCommand
from arartekomaps.categories.models import Category

from arartekomaps.arartekouser.models import ArartekoUser as User

from arartekomaps.places.models import Place, Access, Biblio, Bibtopic, Bibservice

from arartekomaps.locations.models import Location
from arartekomaps.locations.utils import slugify
from datetime import datetime

import xlrd

from arartekomaps.utils.load_images import loadUrlImage
from arartekomaps.settings import IMPORT_FILES_FOLDER

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload places from file (CSV)'
    ADICT = {'inaccesible':'n',
             'no_accesible':'n',
             'no_accesilbe':'n',
             'no_acesible':'n',
             'no_accedible':'n',
             'sin datos': 's',
             'sin_datos': 's',
             '':'s',
             'practicable': 'p',
             'accesible': 'a',
             'accesble':'a'
             }

    BDICT = {'Publikoa':'p',
             'Infantil':'i',
             'Pribatua':'r',
             '':'X'}

    IDICT = {'Ayuntamiento':'ayto',
             'Erakunde autonoma':'auto',
             'Erakunde autonomaa':'auto',
             'Erakunde autonomoa':'auto',
             'Pribatua':'priv',
             '':'XXXX',

    }

    ACDICT = {'Libre':'l',
             '':'X',
    }

    CDICT = {'Publico':'p',
             '':'X'

    }

    BSDICT = {'EGIAZKOA':1,
              1:1,
              'FALTSUA':0,
              '0':0,
              0:0,

    }


    def handle(self, *args, **options):
        saving = len(args)>1 and args[1] or 0
        filename = args[0]
        full_path = "%s/%s" % (IMPORT_FILES_FOLDER,filename)
        f = xlrd.open_workbook(full_path)
        sh = f.sheet_by_index(0)

        kont = 1
        now = datetime.now()
        print 'NOW!:'
        print now

        cat = 'library'
        cat_obj = Category.objects.get(slug=cat)

        for rownum in range(sh.nrows)[1:]:
            fields = sh.row_values(rownum)

            if len(fields)!=51:
                print 'Tenemos mas o menos de 51 campos'
                n = 1
                for field in fields:
                    print n, field
                    n = n+1
                break
            else:
                (cod_origen, titulo, slug, ent_origen, cod_origen_vacio, cat,
                direc1, direc2, cp, pob, city, desc, tel, fax, url,
                email, foto, lat, lon, foto_x, foto_x_tit, foto_x_alt,
                acc_fis, acc_vis, acc_aud, acc_int, acc_org, tipo_biblio,
                ano_inicio, instit, tipo_inst, open_times_eu,
                open_times_es, open_times_s_eu, open_times_s_es,
                tipo_acceso, tipo_centro, tematica_general,
                ser_consulta,
                ser_reprografia, ser_hemeroteca,
                ser_wifi, ser_selectiva, ser_bol_novedades, ser_prestamo,
                ser_prestamo_inter, ser_prestamo_domic, ser_infor_bibliografica,
                ser_internet_usuarios, ser_acceso_bbdd, latlon) = fields[:51]

            # Set fields because not used anymore
            loc = ''
            tipo_biblio = ''
            access_type = ''
            center_type = ''
            tem_general = ''
            institution = ''
            institution_type = ''


            cod_origen = "%d" % cod_origen
            ent_origen = 'ejgv_biblio'
            author = User.objects.get(username=ent_origen)

            location_slug = slugify(city or pob)
            location = Location.objects.filter(slug__startswith=location_slug)
            if location:
                loc_obj = location[0]
            else:
                print 'ERROREA', location_slug
                break

            places = Place.objects.filter(source_id=cod_origen, source=ent_origen)

            if len(places)>0:
                place = places[0]
                print 'EDIT:', place.slug, place.source, place.source_id
            else:
                place = Place()
                place.slug = slugify(titulo, instance=place)
                print 'NEW:', slug, cod_origen

            place.name = titulo
            place.category = cat_obj
            place.description_es = desc
            place.description_eu = desc
            place.description_en = desc
            place.address1 = direc1
            place.address2 = direc2
            if len(cp)<5:
                cp = "0%s" % cp
            place.postalcode = cp.strip()
            place.city = loc_obj
            place.locality = loc
            place.source = ent_origen
            place.source_id = cod_origen
            place.author = author
            try:
                (lat,lon) = latlon.split(',')
            except:
                print 'LATLONERROR', place.slug, latlon
                pass

            if lat:
                place.lat = lat
            if lon:
                place.lon = lon
            print place.lat, place.lon
            place.tlf = tel
            place.fax = fax
            place.url = url
            place.email = email
            place.modified_date = now

            # ACCESS
            place.aphysic = self.ADICT[acc_fis.lower().strip()]
            place.avisual = self.ADICT[acc_vis.lower().strip()]
            place.aaudio = self.ADICT[acc_aud.lower().strip()]
            place.aintelec = self.ADICT[acc_int.lower().strip()]
            place.aorganic = self.ADICT[acc_org.lower().strip()]

            #get photo URL:
            if foto:
                startx = foto.find('img src=')
                endx = foto.find('"', startx+10)
                foto_x = foto[startx+9:endx]

            if saving:
                place.save()

            #Load foto_x
            print foto_x
            t_place = place
            has_point = foto_x.split('/')[-1].find('.')
            if not foto_x_tit:
                foto_x_tit = place.name[:]
            if has_point>-1:
                if saving:
                    image = loadUrlImage(foto_x, t_place, foto_x_tit, 'jpg', )


            

            #BIBLIO
            try:
                biblio = place.biblio.all()[0]
            except:
                biblio = Biblio()
                biblio.place = place

            biblio.btype = self.BDICT[tipo_biblio.strip()]
            if ano_inicio:
                ano_conv = str(int(ano_inicio)).strip().replace('.','')
            else:
                ano_conv = ''
            try:
                biblio.start_year = int(ano_conv)
            except:
                biblio.start_year = 0
            biblio.institution = institution_type
            biblio.institution_type = self.IDICT[institution_type.strip()]
            open_times = "%s %s" % (open_times_eu, open_times_es)
            biblio.open_times = open_times[:250]
            biblio.access_type = self.ACDICT[access_type.strip()]
            biblio.center_type = self.CDICT[center_type.strip()]

            if saving:
                biblio.save()

            tem_infantil = ''
            tem_religioso = ''
            bibtopics = {'general':'1', 'infantil':tem_infantil, 'religioso':tem_religioso}
            for k,v in bibtopics.items():
                if v:
                    bibtopic = Bibtopic.objects.filter(name=k)
                    if bibtopic:
                        bibtopic_obj = bibtopic[0]
                    else:
                        print 'ERROR: no bibtopic called %s' % k
                        bibtopic_obj = Bibtopic()
                        bibtopic_obj.name = k
                        if saving:
                            bibtopic_obj.save()
                    biblio.topics.add(bibtopic_obj)

            bibservices = {'consulta':ser_consulta, 'reprografia':ser_reprografia,
                           'hemeroteca':ser_hemeroteca, 'wifi':ser_wifi, 'selectiva':ser_selectiva,
                           'bol_novedades':ser_bol_novedades, 'prestamo':ser_prestamo,
                           'prestamo_inter':ser_prestamo_inter, 'prestamo_domic':ser_prestamo_domic,
                           'infor_bibliografica':ser_infor_bibliografica, 'internet_usuarios':ser_internet_usuarios,
                           'acceso_bbdd':ser_acceso_bbdd
                           }
            for k,v in bibservices.items():
                if v:
                    bibservice = Bibservice.objects.filter(name=k)
                    if bibservice:
                        bibservice_obj = bibservice[0]
                    else:
                        print 'ERROR: no bibservice called %s' % k
                        bibservice_obj = Bibservice()
                        bibservice_obj.name = k
                        if saving:
                            bibservice_obj.save()
                    biblio.services.add(bibservice_obj)

            if saving:
                biblio.save()
            kont += 1




#* - encoding: utf-8 -*
from django.db import models
from utils import slugify
from django.db.models.signals import pre_save
from arartekomaps.locations.models import Location
from arartekomaps.categories.models import Category
from photologue.models import ImageModel
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
try:
    from django.contrib.auth import get_user_model
    User = settings.AUTH_USER_MODEL
except ImportError:
    from django.contrib.auth.models import User
from django.db.models import Count
from django.core.mail import send_mail
from django.db.models.signals import post_save

DEFAULT_FROM_EMAIL = getattr(settings,'DEFAULT_FROM_EMAIL', '')
EMAIL_NOTIFICATION = getattr(settings,'EMAIL_NOTIFICATION', '')

ACCESS_CHOICES = (
        ('a', 'Accesible'),
        ('p', 'Practicable'),
        ('n', 'No accesible'),
        ('s', 'Sin datos'),
    )


class Place(models.Model):
    slug=models.SlugField(max_length=255, blank=True, null=True, unique=True, help_text=_('Si esta vacio se actualiza al guardar'))
    name=models.CharField(max_length=255, verbose_name=_('Nombre'))
    category=models.ForeignKey(Category, verbose_name=_('Categoria'))
    description =models.TextField(null=True, blank=True, verbose_name=_('Description'), help_text=_('Descripcion del lugar'))
    address1=models.CharField(max_length=100, blank=True, verbose_name=_('Address 1'), help_text=_('Direccion 1 del lugar'))
    address2=models.CharField(max_length=100, blank=True, verbose_name=_('Address 2'), help_text=_('Direccion 2 del lugar'))
    postalcode=models.CharField(max_length=5, blank=True, verbose_name=_('Codigo postal'), help_text=_('Codigo postal del municipio'))
    city=models.ForeignKey(Location, verbose_name=_('Municipio'), help_text=_('Nombre del municipio'))
    locality=models.CharField(max_length=100, blank=True, verbose_name=_('Localidad'), help_text=_('Nombre de localidad'))
    source=models.CharField(max_length=20, blank=True, verbose_name=_('Codigo entidad'))
    source_id=models.CharField(max_length=20, blank=True, verbose_name=_('Codigo origen'), help_text=_('Codigo de la ficha en la base de datos de origen'))
    lat=models.DecimalField(max_digits=12, decimal_places=8,null=True,blank=True, verbose_name=_('Latitud'), help_text=_('Latitud GPS'))
    lon=models.DecimalField(max_digits=12, decimal_places=8,null=True,blank=True, verbose_name=_('Longitud'), help_text=_('Longitud GPS'))
    tlf=models.CharField(max_length=30, blank=True, verbose_name=_('Telefono'), help_text=_('Numero de telefono'))
    fax=models.CharField(max_length=15, blank=True, verbose_name=_('Fax'), help_text=_('Numero de FAX'))
    url_name = models.CharField(max_length=100, blank=True, verbose_name=_('Nombre URL'), help_text=_('Nombre descriptivo del URL'))
    url = models.CharField(max_length=255, blank=True, verbose_name=_('URL'), help_text=_('URL del sitio web'))
    email = models.CharField(max_length=255, blank=True, verbose_name=_('Email'), help_text=_('Email de contacto'))
    aphysic = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Fisica'),default="s", help_text=_('Estado del acceso para minusvalia fisica'))
    avisual = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Visual'),default="s", help_text=_('Estado del acceso para minusvalia visual'))
    aaudio = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Audio'),default="s", help_text=_('Estado del acceso para minusvalia auditiva'))
    aintelec = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Intelectual'),default="s", help_text=_('Estado del acceso para minusvalia intelectual'))
    aorganic = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Organica'),default="s", help_text=_('Estado del acceso para minusvalia organica'))
    adescription = models.TextField(null=True, blank=True, verbose_name=_('Description'), help_text=_('Descripcion de los datos de acceso'))
    afileurl = models.TextField(null=True, blank=True, verbose_name=_('URL ficha'), help_text=_('URL de la ficha'))

    # ALTER TABLE `places_place` ADD `author_id` INT(11) NOT NULL , ADD `added` DATETIME NOT NULL ;
    author = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=_('Autor'))
    added = models.DateTimeField(auto_now_add=True, verbose_name=_('Fecha creacion'))
    modified_date=models.DateTimeField(auto_now=True, verbose_name=_('Fecha Modificacion'))

    # ALTER TABLE `places_place` ADD `is_public` BOOLEAN NOT NULL DEFAULT TRUE ;
    is_public = models.BooleanField(default=True, help_text=_('Mostrar publicamente este lugar'),verbose_name=_('Es publica'))

    def get_comments_count(self):
        return self.parent.all().count()

    def access_list(self):
        access_tuple = (
            ('aphysic', self.aphysic, _('aphysic'), _("access_%s" % self.aphysic)),
            ('avisual', self.avisual, _('avisual'), _("access_%s" % self.avisual)),
            ('aaudio', self.aaudio, _('aaudio'), _("access_%s" % self.aaudio)),
            ('aintelec', self.aintelec, _('aintelec'), _("access_%s" % self.aintelec)),
            ('aorganic', self.aorganic, _('aorganic'), _("access_%s" % self.aorganic))
            )
        return access_tuple

    def access_dict_list(self):
        acc = dict(ACCESS_CHOICES)
        access_dict = {
            'aphysic': acc[self.aphysic],
            'avisual': acc[self.avisual],
            'aaudio': acc[self.aaudio],
            'aintelec': acc[self.aintelec],
            'aorganic': acc[self.aorganic]
        }
        return access_dict

    def access_data(self):
        access_dict = {'description': self.adescription or '', 'fileurl': self.afileurl or '',
                        'aphysic': self.aphysic, 'avisual': self.avisual, 'aaudio': self.aaudio,
                        'aintelec': self.aintelec, 'aorganic': self.aorganic}
        return access_dict

    def biblio_data(self):
        if self.biblio.count()==1:
            biblio = self.biblio.all()[0]
            return biblio
        else:
            return

    def get_places_within_25 (self):
        from django.db import connection, transaction
        cursor = connection.cursor()
        cursor.execute("""SELECT id, (
        3959 * acos( cos( radians(37) ) * cos( radians( lat ) ) *
        cos( radians( lon ) - radians(-122) ) + sin( radians(37) ) *
        sin( radians( lat ) ) ) )
        AS distance FROM places_place HAVING distance < 25000
        ORDER BY distance LIMIT 0 , 10;""")
        ids = [row[0] for row in cursor.fetchall()]

        return Place.objects.filter(id__in=ids)

    def nearby_locations(self, radius=2, max_results=10, use_miles=False):
        latitude = self.lat
        longitude =self.lon
        if use_miles:
            distance_unit = 3959
        else:
            distance_unit = 6371

        from django.db import connection, transaction
        cursor = connection.cursor()

        sql = """SELECT id, (%f * acos( cos( radians(%f) ) * cos( radians( lat ) ) *
        cos( radians( lon ) - radians(%f) ) + sin( radians(%f) ) * sin( radians( lat ) ) ) )
        AS distance FROM places_place WHERE (%f * acos( cos( radians(%f) ) * cos( radians( lat ) ) *
        cos( radians( lon ) - radians(%f) ) + sin( radians(%f) ) * sin( radians( lat ) ) ) ) < %d
        ORDER BY distance LIMIT 0 , %d;""" % (distance_unit, latitude, longitude, latitude ,distance_unit, latitude, longitude, latitude, int(radius), max_results)
        cursor.execute(sql)

        dist_dict = {}
        for row in cursor.fetchall():
            k, v = row[0], row[1]
            dist_dict[k] = v
        ids = dist_dict.keys()
        objs = Place.objects.filter(id__in=ids)
        all_objs = [(int(dist_dict[obj.id]*1000),obj) for obj in objs]
        all_objs.sort()
        return all_objs[1:]

    def icon(self):
        return self.category.icon()

    def get_absolute_url(self):
        return "/p/%s/" % (self.slug)

    def __unicode__(self):
        return self.name

    def save(self):
        if hasattr(self, 'custom_date'):
            self.modified_date = self.custom_date
        super(Place, self).save()



class Access(models.Model):
    aphysic = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Fisica'))
    avisual = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Visual'))
    aaudio = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Audio'))
    aintelec = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Intelectual'))
    aorganic = models.CharField(max_length=1, choices=ACCESS_CHOICES, verbose_name=_('Organica'))
    description = models.TextField(null=True, blank=True, verbose_name=_('Description'))
    fileurl = models.TextField(null=True, blank=True, verbose_name=_('URL ficha'))
    place = models.ForeignKey(Place, unique=True, verbose_name=_('Place'), related_name='access')

class Bibtopic(models.Model):
    """ """
    name = models.CharField(max_length=50, verbose_name=_('Nombre'))

    def __unicode__(self):
        return self.name

class Bibservice(models.Model):
    """ """
    name = models.CharField(max_length=50, verbose_name=_('Nombre'))

    def __unicode__(self):
        return self.name

class Biblio(models.Model):
    """ """
    BTYPE_CHOICES = (
        ('p', 'Publico'),
        ('r', 'Privado'),
        ('i', 'Infantil'),
        ('v', 'Investigacion'),
        ('t', 'Patrimonial'),
        ('e', 'Especializada')
    )
    btype = models.CharField(max_length=1, choices=BTYPE_CHOICES, blank=True, verbose_name=_('Tipo'))
    start_year = models.DecimalField(max_digits=4, decimal_places=0,null=True,blank=True, verbose_name=_('Ano inicio'))
    institution = models.CharField(max_length=100, blank=True, verbose_name=_('Institucion'))
    INST_TYPE_CHOICES = (
        ('ayto', 'Ayuntamiento'),
        ('auto', 'Autónoma'),
        ('priv', 'Privado'),
        ('fora', 'Foral'),
    )
    institution_type = models.CharField(max_length=4, choices=INST_TYPE_CHOICES, blank=True, verbose_name=_('Tipo institucion'))
    open_times = models.CharField(max_length=255, null=True,blank=True, verbose_name=_('Horario apertura'))
    ACCESS_TYPE_CHOICES = (
        ('l', 'Libre'),
        ('r', 'Restringido'),
    )
    access_type = models.CharField(max_length=1, choices=ACCESS_TYPE_CHOICES, blank=True, verbose_name=_('Tipo de acceso'))
    CENTER_TYPE_CHOICES = (
        ('p', 'Público'),
    )
    center_type = models.CharField(max_length=1, choices=CENTER_TYPE_CHOICES, blank=True, verbose_name=_('Tipo de centro'))
    topics = models.ManyToManyField(Bibtopic, verbose_name=_('Temas'))
    services = models.ManyToManyField(Bibservice, verbose_name=_('Servicios'))
    place=models.ForeignKey(Place, unique=True, verbose_name=_('Place'), related_name='biblio')

class MPhoto(ImageModel):
    name=models.CharField(max_length=255, verbose_name=_('Nombre'), blank=True)
    place=models.ForeignKey(Place, verbose_name=_('Place'))
    user=models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=_('User'), blank=True, null=True)
    def_img = models.BooleanField(verbose_name=_('Default img'),default=False)

    def __unicode__(self):
        return self.name or self.place.name


def generate_place_slug(sender, instance, **kwargs):
    if not instance.slug:
        slug_proposal = slugify(u'%s' % (instance.name))
        prev_slug = Place.objects.filter(slug__startswith=slug_proposal).exclude(pk=instance.pk)
        if prev_slug:
            slug_proposal += u'-%s' % len(prev_slug)
        instance.slug = slug_proposal
pre_save.connect(generate_place_slug, sender=Place)


def send_image_notification(sender, instance, created, **kwargs):
    if created:
        send_mail('[IRUDI BERRIA] ', 'Irudi berri bat gorde da: '+instance.name+'\n\n'+settings.HOST+'/admin/places/mphoto/' + str(instance.id), DEFAULT_FROM_EMAIL,
            [EMAIL_NOTIFICATION], fail_silently=True)
    return True

def send_place_email(sender,instance, created, **kwargs):
    if created:
        send_mail('[LEKU BERRIA] ', 'Leku berri bat gorde da: '+instance.name+'\n\n'+settings.HOST+'/admin/places/place/' + str(instance.id), DEFAULT_FROM_EMAIL,
            [EMAIL_NOTIFICATION], fail_silently=True)

post_save.connect(send_image_notification, sender=MPhoto)
post_save.connect(send_place_email, sender=Place)


from django.conf import settings
from django import forms
from models import Place,Location
from arartekomaps.categories.models import Category
from django.utils.translation import ugettext_lazy as _

class PlaceForm(forms.ModelForm):
    city = forms.ModelChoiceField(label=_('City'),queryset=Location.objects.filter(level=2).order_by('name'), help_text=_('Nombre del municipio'))
    category = forms.ModelChoiceField(label=_('Category'),queryset=Category.objects.filter(parent__isnull=False).order_by('name'), help_text=_('Elige una categoria del lugar'))
    address1 = forms.CharField(label=_('Address'), widget=forms.TextInput(attrs={'size':'20'}), help_text=_('Direccion 1 del lugar'))
    address2 = forms.CharField(label='', widget=forms.TextInput(attrs={'size':'20'}), help_text=_('Direccion 2 del lugar'),required=False)
    afileurl = forms.CharField(label=_('URL externa'), widget=forms.TextInput(attrs={'size':'20'}), help_text=_('Pagina web externa con informacion detallada sobre la accesibilidad del recurso'),required=False)

    class Meta:
        model = Place
        exclude = ('slug','author','description','source','adescription','url','url_name')


from django.db import models
from cssocialuser.models import CSAbstractSocialUser
from django.conf import settings
from django.core.mail import send_mail
from django.contrib.auth.models import UserManager

MEMBER_PHOTO_SLUG=getattr(settings,'PROFILE_PHOTO_DEFAULT_SLUG','no-profile-photo')


class ArartekoUser(CSAbstractSocialUser):
    is_editor = models.BooleanField(default=False)
    last_updated = models.DateTimeField(auto_now_add=True,editable=False)
    date_joined  = models.DateTimeField(auto_now_add=True,editable=False)

    objects = UserManager()

    USERNAME_FIELD = 'username'
    REQUIRED_FIELDS = ['email']

    def get_profile(self):
        return self

    def getFullName(self):
        return self.get_full_name() or self.username

    def email_user(self, subject, message, from_email=None, **kwargs):
        """
        Sends an email to this User.
        """
        send_mail(subject, message, from_email, [self.email], **kwargs)

    def get_fullname(self):
        return self.fullname or self.username

    def __unicode__(self):
        return u'%s' % self.username

    class Meta:
        verbose_name = 'Ararteko erabiltzailea'
        verbose_name_plural = 'Ararteko erabiltzailea'


from django.core.management.base import BaseCommand
from arartekomaps.categories.models import Category
from arartekomaps.places.models import Place, Access, Biblio, Bibtopic, Bibservice, MPhoto
from arartekomaps.arartekouser.models import ArartekoUser as User
from arartekomaps.locations.models import Location
from arartekomaps.locations.utils import slugify
import xlrd, StringIO, urllib2
from arartekomaps.utils.load_images import loadUrlImage
from arartekomaps.settings import IMPORT_FILES_FOLDER

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload places from file (CSV)'
    ADICT = {'inaccesible':'n',
             'no_accesible':'n',
             'no accesible':'n',
             'sin datos': 's',
             'sin_datos': 's',
             '':'s',
             'practicable': 'p',
             'accesible': 'a'}
    
    RDICT = {'restaurante':'restaurant',
            'sidreria':'sidreria',
            'asador':'asador',
            'bodega-de-vino-rioja-alavesa':'bodega-rioja',
            'bodega-de-txakoli':'bodega-txakoli',
            'comida-rapida':'fast-food',
            'pasteleria-confiteria':'pasteleria'
            }
     
    def handle(self, *args, **options):
        saving = len(args)>1 and args[1] or 0 
        filename = args[0]
        line = len(args)>2 and int(args[2]) or 1
        full_path = "%s/%s" % (IMPORT_FILES_FOLDER,filename)
        f = xlrd.open_workbook(full_path)
        sh = f.sheet_by_index(0)
        kont = 1
        ercnt =1
        
        CDICT = {'legutiano':'legutio',
                 'ribera-alta':'erriberagoitia', 
        }

        uloc = {}

        for rownum in range(sh.nrows)[line:]:
            fields = sh.row_values(rownum)

            if len(fields)!=24:
                print 'Tenemos mas o menos de 24 campos'
                n = 1
                for field in fields:
                    print n, field
                    n = n+1
                break
            else:
                (titulo, slug, ent_origen, cod_origen,
                direc1, direc2, cp, pob, loc, desc, lat, lon, tel, fax, url, 
                foto_x, foto_x_tit, foto_x_alt, itinerarios, 
                acc_fis, acc_vis, acc_aud, acc_int, 
                acc_org ) = fields[:25]
                
            
            
            translation = False
            ent_origen = 'ejgv-tur-infos'
            places = Place.objects.filter(source_id=cod_origen, source=ent_origen)
            if len(places)<1:
                places = Place.objects.filter(source_id=str(int(cod_origen)), source=ent_origen)
            if len(places)>0:
                place = places[0]
            if '_eu' in filename and place:
                place.description_eu = desc
                translation = True
            elif '_en' in filename and place:
                place.description_en = desc
                translation = True
            elif '_eu' in filename or '_en' in filename:
                translation = True

            if translation:
                place.save()
                continue



            if 'oficinas' in filename:
                cat_obj = Category.objects.get(slug='tourist-office')
            elif 'centros' in filename:
                cat_obj = Category.objects.get(slug='interpretation-centre')
            else:
                cat_obj = Category.objects.get(slug='tourism')
                                 
            #GET USER
            author = User.objects.get(username=ent_origen)
                   
            location_slug = slugify(pob)

            if CDICT.has_key(location_slug):
                location_slug = CDICT[location_slug]           
            location = Location.objects.filter(slug__startswith=location_slug)
            if location:
                loc_obj = location[0]
            else:
                print ercnt,'WARNING: New place', titulo, cp, pob, kont
                uloc[pob]=uloc.get(pob,0)+1
                ercnt = ercnt+1
                break

            if len(places)>0:
                place = places[0]
                print 'EDIT:', place.slug, cod_origen
            else:
                place = Place()
                print slug
                place.slug = slugify(slug.split('/')[2],instance=place)
                print 'NEW:', slug, cod_origen
            

            place.name = titulo
            place.category = cat_obj
            place.description_es = desc
            place.address1 = direc1
            place.address2 = direc2
            if len(cp)<5:
                cp = "0%s" % cp
            place.postalcode = cp.strip()
            try:
                place.city = loc_obj
            except:
                pass
            place.locality = pob != loc and loc or ""
            place.description = desc

            #SET USER
            place.author = author
            place.source = ent_origen
            place.source_id = "%d" % int(cod_origen)
            if lat:
                place.lat = str(lat)
            if lon:
                place.lon = str(lon)
            place.tlf = ''.join(tel[:30].split())
            place.fax = ''.join(fax[:15].split())
            place.url = url
            place.email = ''
            if saving:
                place.save()
            
            accesses = Access.objects.filter(place=place)
            if len(accesses)>0:
                access = accesses[0]
            else:
                access = Access()
                access.place = place
            access.aphysic = self.ADICT[acc_fis.lower().strip()]
            access.avisual = self.ADICT[acc_vis.lower().strip()]
            access.aaudio = self.ADICT[acc_aud.lower().strip()]
            access.aintelec = self.ADICT[acc_int.lower().strip()]
            access.aorganic = self.ADICT[acc_org.lower().strip()]
            
            if saving:
                access.save()

            #print foto_x
            t_place = place
            has_point = foto_x.split('/')[-1].find('.')
            if has_point>-1:
                if saving:
                    image = loadUrlImage(foto_x, t_place, foto_x_tit, 'jpg', )
            kont += 1

        print uloc
        



#* - encoding: utf-8 -*
from django.db import models
from utils import slugify
from django.db.models.signals import pre_save


class Location(models.Model):
    name = models.CharField(max_length=100)
    parent = models.ForeignKey('self', null=True, blank=True, related_name='child_set')
    slug = models.SlugField(blank=True)
    level = models.IntegerField()
    lat=models.DecimalField(max_digits=12, decimal_places=8,null=True,blank=True)
    lon=models.DecimalField(max_digits=12, decimal_places=8,null=True,blank=True)

    class Meta:
        verbose_name_plural = ('locations')
        unique_together = ('parent', 'name')
 
    def __repr__(self):
        return '<Location %s>' % self
    
    def __unicode__(self):
        return self.name
    
    def get_absolute_url(self):
        if self.level==0:
            return "/l/"
        elif self.level==1:
            return "/l/%s/" % self.slug
        elif self.level==2:
            return "/l/%s/%s/" % (self.parent.slug,self.slug)
        else:
            return '/bad_url/'
    
    def save(self):
        super( Location, self ).save()

def generate_location_slug(sender, instance, **kwargs):
    if not instance.slug:
        slug_proposal = slugify(u'%s' % (instance.name))
        prev_slug = Location.objects.filter(slug__startswith=slug_proposal)
        if prev_slug:
            slug_proposal += u'-%s' % len(prev_slug)
        instance.slug = slug_proposal
        
def generate_location_level(sender, instance, **kwargs):
    if instance.parent:
        instance.level=instance.parent.level+1
    else:
        instance.level=0
        
pre_save.connect(generate_location_slug, sender=Location)
pre_save.connect(generate_location_level, sender=Location)



from django.core.management.base import BaseCommand
from arartekomaps.places.models import Place

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload place lat lon from file (CSV)'

    def handle(self, *args, **options):
        f = open(args[0],'r')
        cnt = 1
        for pl in f.readlines():
            print cnt
            (source_id,lat,lon)=pl.split('\t')[0:24]
            place = Place.objects.get(source_id=source_id) 
            print place.slug, place.lat, place.lon
            print lat,lon
            place.lat = lat
            place.lon = lon
            place.save()



from django.template.defaultfilters import stringfilter

from django import template
register = template.Library()

@register.filter(name='normaltxo')
@stringfilter
def normaltxo(value):
    trans = {'Frantzisko':'Franzisko',
             'Inazio':'Ignazio',
             'Miguel Urruzuno':'Migel Urruzuno',
             'Ermuaranbide':'Ermuaran',
             'Lorenzo':'Lorentzo'}
    for k,v in trans.items():
        value = value.replace(k,v)
    return value


@register.filter(name='get_username')
def get_username(images):
    image = images[0]
    return image.user.get_full_name()


import re
import unicodedata
from htmlentitydefs import name2codepoint
from django.utils.encoding import smart_unicode, force_unicode
         
def slugify(s, entities=True, decimal=True, hexadecimal=True,
   instance=None, slug_field='slug', filter_dict=None):
    s = smart_unicode(s)

    #character entity reference
    if entities:
        s = re.sub('&(%s);' % '|'.join(name2codepoint), lambda m: unichr(name2codepoint[m.group(1)]), s)

    #decimal character reference
    if decimal:
        try:
            s = re.sub('&#(\d+);', lambda m: unichr(int(m.group(1))), s)
        except:
            pass

    #hexadecimal character reference
    if hexadecimal:
        try:
            s = re.sub('&#x([\da-fA-F]+);', lambda m: unichr(int(m.group(1), 16)), s)
        except:
            pass

    #translate
    s = unicodedata.normalize('NFKD', s).encode('ascii', 'ignore')

    #replace unwanted characters
    s = re.sub(r'[^-a-z0-9]+', '-', s.lower())

    #remove redundant -
    s = re.sub('-{2,}', '-', s).strip('-')

    slug = s
    if instance:
        def get_query():
            query = instance.__class__.objects.filter(**{slug_field: slug})
            if filter_dict:
                query = query.filter(**filter_dict)
            if instance.pk:
                query = query.exclude(pk=instance.pk)
            return query
        counter = 1
        while get_query():
            slug = "%s-%s" % (s, counter)
            counter += 1
    return slug
    


from django.core.management.base import BaseCommand
from arartekomaps.categories.models import Category
from arartekomaps.places.models import Place, Access, Biblio, Bibtopic, Bibservice

from arartekomaps.locations.models import Location
from arartekomaps.locations.utils import slugify
from datetime import datetime

import xlrd

from arartekomaps.utils.load_images import loadUrlImage
from arartekomaps.settings import IMPORT_FILES_FOLDER

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload places from file (CSV)'
    ADICT = {'inaccesible':'n',
             'no_accesible':'n',
             'no_accesilbe':'n',
             'no_acesible':'n',
             'no_accedible':'n',
             'no accesible':'n',
             'sin datos': 's',
             'sin_datos': 's',
             '':'s',
             'practicable': 'p',
             'accesible': 'a',
             'accesble':'a'
             }
    CATDICT = {
            'Bares':'bar',
            'Restaurante':'restaurant',
            u'Pasteler\xeda':'pasteleria',
            'Otros':'eat',
            u'Comida r\xe1pida':'fast-food',
            u'Comida R\xe1pida':'fast-food',
            u'Sidrer\xeda':'sidreria',
            }

    def handle(self, *args, **options):
        saving = 1
        filename = args[0]
        full_path = "%s/%s" % (IMPORT_FILES_FOLDER,filename)
        f = xlrd.open_workbook(full_path)
        sh = f.sheet_by_index(0)

        kont = 1
        now = datetime.now()
        print 'NOW!:'
        print now


        for rownum in range(sh.nrows)[2:]:
            fields = sh.row_values(rownum)

            if len(fields)!=19:
                print 'Tenemos mas o menos de 19 campos'
                n = 1
                for field in fields:
                    print n, field
                    n = n+1
                break
            else:
                (name, catname, address1, postalcode,
                city_name, province, lat,
                 lon, tlf,
                 acc_fis, acc_vis, acc_aud, acc_int, acc_org,
                 acc_desc, xw, xx, xy, xz) = fields[:19]

            """slug
                name
                category.slug
                description
                address1
                address2
                postalcode
                city.name
                locality
                source
                source_id
                lat
                lon
                tlf
                fax
                url
                email
                access.aphysic
                access.avisual
                access.aaudio
                access.aintelec
                access.aorganic
                access.description
                access.fileurl
            """

            location_slug = slugify(city_name)
            try:
                location = Location.objects.get(slug=location_slug)
                loc_obj = location
            except:
                location = Location.objects.filter(slug__startswith=location_slug)
                if location:
                    loc_obj = location[0]
                else:
                    print 'ERROREA', location_slug
                    break
            print location, city_name, location_slug

            # Line added to force slug creation for the first import
            slug = "abcdefghijklmnopqrs"
            source_id = "%04d" % rownum
            source = 'elkartu'


            cat = self.CATDICT[catname]
            cat_obj = Category.objects.get(slug=cat)


            places = Place.objects.filter(slug=slug)

            if len(places)>0:
                place = places[0]
                print 'EDIT:', place.slug, place.source, place.source_id
            else:
                place = Place()
                place.slug = slugify(name, instance=place)
                print 'NEW:', place.slug, source_id
            place.name = name.encode('utf-8')
            place.category = cat_obj
            place.description_es = ''
            place.description_eu = ''
            place.description_en = ''
            place.address1 = address1
            place.address2 = ''
            cp = str(int(postalcode))
            if len(cp)<5:
                cp = "0%s" % cp
            place.postalcode = cp.strip()
            place.city = loc_obj
            place.locality = ''
            place.source = source
            place.source_id = source_id
            latstr = str(lat)[:-2]
            if type(lon)==type(0.3):
                lonstr =str(lon)[:-2]
            else:
                lonstr = lon
            place.lat = "%s.%s" % (latstr[:2],latstr[2:])
            place.lon = "%s.%s" % (lonstr[:2],lonstr[2:])
            print place.lat
            print place.lon
            place.tlf = tlf
            place.fax = ''
            place.url = ''
            place.email = ''
            place.modified_date = now

            if saving:
                place.save()

            # ACCESS
            try:
                access = place.access.all()[0]
            except:
                access = Access()
                access.place = place

            access.aphysic = self.ADICT[acc_fis.lower().strip()]
            access.avisual = self.ADICT[acc_vis.lower().strip()]
            access.aaudio = self.ADICT[acc_aud.lower().strip()]
            access.aintelec = self.ADICT[acc_int.lower().strip()]
            access.aorganic = self.ADICT[acc_org.lower().strip()]
            access.description = acc_desc

            if saving:
                access.save()

            kont += 1




# Create your views here.
from django.shortcuts import render_to_response, get_object_or_404
from django.http import Http404
from django.template import RequestContext
from arartekomaps.settings import STATIC_URL
from arartekomaps.locations.models import Location
from arartekomaps.places.models import Place
from arartekomaps.categories.models import Category
from django.core.paginator import Paginator
from django.utils.translation import ugettext_lazy as _


def split_seq(seq, num_pieces):
    """ Split a list in n groups. Useful for listings in cols """
    start = 0
    for i in xrange(num_pieces):
        stop = start + len(seq[i::num_pieces])
        yield seq[start:stop]
        start = stop


def listing(request, state):
    """ Listing cities in an state (probintziak) """
    mystate = Location.objects.get(slug=state)
    cities = Location.objects.filter(parent=mystate).order_by('name')
    city_slices = split_seq(cities, 4)
    hidesearch = True
    return render_to_response('listing.html', locals(), context_instance=RequestContext(request)
    )
    
def location(request,state,city,maincat='',subcat=''):
    """ Default view for a city """

    pagenumber = request.GET.get('page','1')
    if int(pagenumber)<1:
        pagenumber = 1
    
    city = get_object_or_404(Location, slug=city)

    rootcats = []
    subcats = []
    places_here = Place.objects.filter(city=city,is_public=True)
    for mplace in places_here:
        thiscat = mplace.category
        rootcat = thiscat.get_root()
        if rootcat not in rootcats:
            rootcats.append(rootcat)
        if maincat and maincat==rootcat.slug and thiscat.get_level()>0 and not thiscat in subcats:
            subcats.append(thiscat)

    if maincat:
        if subcat:
            parentcat = get_object_or_404(Category, slug=maincat) 
            childcat = get_object_or_404(Category, slug=subcat)
            pagetitle = _("%(parentcatname)s: %(childcatname)s in %(cityname)s") % {'parentcatname': parentcat.name, 'childcatname': childcat.name, 'cityname': city.name}
            places = Place.objects.filter(city=city, category=childcat,is_public=True)
        else:    
            parentcat = get_object_or_404(Category, slug=maincat)
            pagetitle = _("%(parentcatname)s in %(cityname)s") % {'parentcatname': parentcat.name, 'cityname':city.name}
            places = Place.objects.filter(city=city, is_public=True, category__in=parentcat.get_descendants(include_self=True))
        pass
    else:
        places = Place.objects.filter(city=city,is_public=True)
        pagetitle = city.name     

    pages = Paginator(places,10)
    try:
        thispage = pages.page(int(pagenumber))
    except:
        raise Http404

    p_places = thispage.object_list

    prev_pars = request.GET.copy()
    next_pars = request.GET.copy()
    if pagenumber == '1':
        prev_pars.update({'page':'1'})
    else:
        prev_pars.update({'page':thispage.previous_page_number()})
    try:
        next_pars.update({'page':thispage.next_page_number()})
    except:
        next_pars.update({'page':'1'})
    prev_url = "/filter/?%s" % "&".join(["%s=%s" % (k,v) for k,v in prev_pars.items()])
    next_url = "/filter/?%s" % "&".join(["%s=%s" % (k,v) for k,v in next_pars.items()])

    if pagenumber == '1':
        prev_url = "%s?page=%d" % (request.path,1)
    else:
        prev_url = "%s?page=%d" % (request.path,thispage.previous_page_number())
    try:
        next_url = "%s?page=%d" % (request.path,thispage.next_page_number())
    except:
        next_url = "%s?page=%d" % (request.path,1)
    return render_to_response('location.html', locals(), context_instance=RequestContext(request)
    )


from django.core.management.base import BaseCommand
from arartekomaps.categories.models import Category
from arartekomaps.places.models import Place, Access, Biblio, Bibtopic, Bibservice

from arartekomaps.locations.models import Location
from arartekomaps.locations.utils import slugify
from datetime import datetime

import xlrd

from arartekomaps.utils.load_images import loadUrlImage
from arartekomaps.settings import IMPORT_FILES_FOLDER

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload places from file (CSV)'
    ADICT = {'inaccesible':'n',
             'no_accesible':'n',
             'no_accesilbe':'n',
             'no_acesible':'n',
             'no_accedible':'n',
             'no accesible':'n',
             'sin datos': 's',
             'sin_datos': 's',
             '':'s',
             'practicable': 'p',
             'accesible': 'a',
             'accesble':'a'
             }

    def handle(self, *args, **options):
        saving = 1
        filename = args[0]
        full_path = "%s/%s" % (IMPORT_FILES_FOLDER,filename)
        f = xlrd.open_workbook(full_path)
        sh = f.sheet_by_index(0)

        kont = 1
        now = datetime.now()
        print 'NOW!:'
        print now

        cat = 'train'
        cat_obj = Category.objects.get(slug=cat)

        for rownum in range(sh.nrows)[1:]:
            fields = sh.row_values(rownum)

            if len(fields)!=24:
                print 'Tenemos mas o menos de 24 campos'
                n = 1
                for field in fields:
                    print n, field
                    n = n+1
                break
            else:
                (slug, name, cat_slug, description, address1, address2,
                 postalcode, city_name, locality, source, source_id, lat,
                 lon, tlf, fax, url, email,
                 acc_fis, acc_vis, acc_aud, acc_int, acc_org,
                 acc_desc, acc_fileurl) = fields[:24]
            
            """slug
                name
                category.slug
                description
                address1
                address2
                postalcode
                city.name
                locality
                source
                source_id
                lat
                lon
                tlf
                fax
                url
                email
                access.aphysic
                access.avisual
                access.aaudio
                access.aintelec
                access.aorganic
                access.description
                access.fileurl
            """

            location_slug = slugify(city_name)
            location = Location.objects.filter(slug__startswith=location_slug)
            if location:
                loc_obj = location[0]
            else:
                print 'ERROREA', location_slug
                break
            print location_slug, location
            kont += 1




from django.contrib import admin
from arartekomaps.locations.models import Location
from django import forms
from django.template.loader import render_to_string

class mapWidget(forms.widgets.Input):
    """ """
    input_type = None
    def render(self, name, value, attrs=None):
        return render_to_string('mapwidget.html', locals())

class LocationAdminForm(forms.ModelForm):
    map = forms.CharField(widget=mapWidget(), required=False) 
    class Meta:
        model = Location
        fields = ('name','slug','parent','level','lat','lon','map')

class LocationAdmin(admin.ModelAdmin):
    form = LocationAdminForm
    list_display = ('name','slug','lat','lon')
    readonly_fields = ()
    search_fields = ('name',)
    filter_fields = ('lat',)
    
admin.site.register(Location, LocationAdmin)




from django.core.management.base import BaseCommand
from django.utils.html import strip_tags
import csv
import time
from django.template import loader, Context
from arartekomaps.places.models import Place

def export_places():
    places = Place.objects.all()

 #    with open('../media/places/places_'+str(time.strftime("%Y-%m-%d"))+'.csv', 'wb') as csvfile:
 #        str_writer = csv.writer(csvfile, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)

 #        str_writer.writerow(["Name","Category","Address 1","Address 2","City","Postal Code","Locality","Telephone","Fax","URL","Email","Latitude","Longitude","Description"])
	# for place in places:
	#     str_writer.writerow([(place.name or '').encode('ascii', 'ignore'),(place.category.name or '').encode('ascii', 'ignore'),(place.address1 or '').encode('ascii', 'ignore'),(place.address2 or '').encode('ascii', 'ignore'),(place.city.name or '').encode('ascii', 'ignore'),(place.postalcode or '').encode('ascii', 'ignore'),(place.locality or '').encode('ascii', 'ignore'),(place.tlf or '').encode('ascii', 'ignore'),(place.fax or '').encode('ascii', 'ignore'),(place.url or '').encode('ascii', 'ignore'),(place.email or '').encode('ascii', 'ignore'),(str(place.lat) or ''),(str(place.lon) or ''),strip_tags((place.description or '')).encode('ascii', 'ignore')])

    t = loader.get_template('csv_export.txt')
    c = Context({
        'places': places,
    })

    myFile = open('../media/places/places_'+str(time.strftime("%Y-%m-%d"))+'.csv', 'w')
    myFile.write(t.render(c).encode('ascii', 'ignore'))
    myFile.close()

    return True

class Command(BaseCommand):
    help = 'Export places'

    def handle(self, *args, **options):
        export_places()


from django.db import models
from mptt.models import MPTTModelBase, MPTTModel

class Category(MPTTModel):

    parent = models.ForeignKey('self', blank=True, null=True, related_name='children')
    name = models.CharField(max_length=50, unique=True)
    slug = models.CharField(max_length=255,unique=True, blank=True, null=True, help_text="Se actualiza al guardar")
       
    class MPTTMeta:
        order_insertion_by = ['name']
        parent_attr = 'parent'

    def get_absolute_url(self):
        return "/c/%s" % self.slug
    
    def get_node_slug(self):
        return self.slug
    
    def str2trans(self):
        return "cat_%s" % self.slug
        
    def icon(self):
        maincat = self
        while maincat.parent:
            maincat = maincat.parent
        return maincat.slug
        
    def __unicode__(self):
        return self.name


from django.core.management.base import BaseCommand
from django.core.mail import send_mail
from django.conf import settings

DEFAULT_FROM_EMAIL = getattr(settings,'DEFAULT_FROM_EMAIL', '')

EMAIL_HOST = getattr(settings,'EMAIL_HOST', '')
EMAIL_HOST_USER = getattr(settings,'EMAIL_HOST_USER', '')
EMAIL_HOST_PASSWORD = getattr(settings,'EMAIL_HOST_PASSWORD', '')

class Command(BaseCommand):
    args = ''
    help = 'Test email server'
    
    def handle(self, *args, **options):
        send_mail('Testing email', 'If you receive this message, everything is all right', 
            DEFAULT_FROM_EMAIL, ['uodriozola@codesyntax.com'], fail_silently=False)
    



from django.conf.urls.defaults import patterns, include, url
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.http import HttpResponse
from django.contrib import admin
from settings import MEDIA_ROOT

admin.autodiscover()

urlpatterns = patterns('',

    url(r'^$', 'arartekomaps.views.home', name='home'),
    (r'^robots.txt$', lambda r: HttpResponse("User-agent: *\nDisallow: /u/login ", mimetype="text/plain")),
    url(r'^set_lang/$', 'arartekomaps.views.set_language', name='set_lang'),

    url(r'^p/save_location/$', 'arartekomaps.places.views.save_location', name='savelocation'),
    url(r'^p/(?P<slug>[^/]+)/$', 'arartekomaps.places.views.placeview', name='place'),
    url(r'^p/(?P<slug>[^/]+)/locateme$', 'arartekomaps.places.views.locateme', name='locateme'),
    url(r'^p/(?P<slug>[^/]+)/addphoto/$', 'arartekomaps.places.views.addPhoto', name='addPhoto'),

    # url(r'^search/$', 'arartekomaps.views.search', name='search'),
    url(r'^gsearch/$','arartekomaps.views.gsearch',name='gsearch'),

    url(r'^filter/$', 'arartekomaps.views.filter', name='filter'),

    url(r'^l/', include('arartekomaps.locations.urls')),

    # Uncomment the admin/doc line below to enable admin documentation:
    # url(r'^admin/doc/', include('django.contrib.admindocs.urls')),

    url(r'^comments/', include('django.contrib.comments.urls')),
    url(r'^admin/', include(admin.site.urls)),

    url(r'^u/$','django.contrib.auth.views.login', name='erabiltzailea_user_login'),
    url(r'^u/my_places/$','arartekomaps.places.views.my_places', name='edit_places'),
    url(r'^u/new_place/$','arartekomaps.places.views.new_place', name='new_place'),
    url(r'^u/delete_place/(?P<slug>[^/]+)/$','arartekomaps.places.views.delete_place', name='delete_place'),
    url(r'^u/edit_place/(?P<slug>[^/]+)/$','arartekomaps.places.views.edit_place', name='edit_place'),

    (r'^u/', include('cssocialuser.urls')),
    (r'^photologue/', include('photologue.urls')),

    (r'^api/', include('arartekomaps.api.urls')),

    url(r'^pg/', include('pages.urls')),
    (r'^media/places/$', 'django.views.static.serve',{'document_root': MEDIA_ROOT+'/places/'}),
    (r'^media/places/(?P<path>.*)$', 'django.views.static.serve',{'document_root': MEDIA_ROOT+'/places/'}),
)

urlpatterns += staticfiles_urlpatterns()


from django.core.management.base import BaseCommand
from arartekomaps.categories.models import Category
from arartekomaps.places.models import Place, Access
from arartekomaps.locations.models import Location
from arartekomaps.locations.utils import slugify

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload places from file (CSV)'
    ADICT = {'inaccesible':'n',
             'sin datos': 's',
             'practicable': 'p',
             'accesible': 'a'}

    def handle(self, *args, **options):
        f = open(args[0],'r')
        parent = Location.objects.get(slug='gipuzkoa')
        #fix this, location's parent must be described in data file
        kont = 1
	for pl in f.readlines():
            print kont
            titulo, slug, ent_origen, cod_origen, cat, direc, cp, pob, desc, tel, fax, url, foto, lat, lon, foto_x, foto_x_tit, itinerarios, foto_x_alt, acc_fis, acc_vis, acc_aud, acc_int, acc_org = pl.split('\t')[0:24]
            cat_obj = Category.objects.get(slug=cat)
            location_slug =slugify(pob)
            location = Location.objects.filter(slug__startswith=location_slug)

            if location:
                loc_obj = location[0]
            else:
                loc_obj = Location()
                loc_obj.name = pob.decode('utf-8')
                loc_obj.parent = parent
                loc_obj.save()
            place = Place()
            place.name = titulo.decode('utf-8')
            place.category = cat_obj
            place.description = desc.decode('utf-8')
            place.address1 = direc
            place.postalcode = cp
            place.city = loc_obj
            place.source = ent_origen
            place.source_id = cod_origen
            if lat:
                place.lat = lat
            if lon:
                place.lon = lon
            place.tlf = tel
            place.fax = fax
            place.url = url
            place.save()
            access = Access()
            access.aphysic = self.ADICT[acc_fis.lower().strip()]
            access.avisual = self.ADICT[acc_vis.lower().strip()]
            access.aaudio = self.ADICT[acc_aud.lower().strip()]
            access.aintelec = self.ADICT[acc_int.lower().strip()]
            access.aorganic = self.ADICT[acc_org.lower().strip()]
            access.place = place
            access.save()
            kont += 1




from django.core.management.base import BaseCommand
from arartekomaps.categories.models import Category
from arartekomaps.places.models import Place

class Command(BaseCommand):
    args = 'file_abs_path'
    help = 'Upload places from file (CSV)'

    def handle(self, *args, **options):
        cats = Category.objects.all()
        for cat in cats:
            places = Place.objects.filter(category=cat)
            print cat.name, len(places)        



from arartekomaps.places.models import MPhoto
from photologue.models import Photo
from urllib2 import urlopen
from django.core.files.base import ContentFile
from arartekomaps.utils.slug import time_slug, time_slug_long, time_slug_string

from cStringIO import StringIO
try:
    from PIL import Image
except ImportError:
    import Image

import socket
socket.setdefaulttimeout(20)
import cgi

def _getUrlImage(url):
    """ """    
    url1 = url.replace(' ','%20')
    try:
        mysocket = urlopen(url1)
    except:
        mysocket = None
    return mysocket


def loadUrlImage(url, place, name='', format='jpg'):
    """ 
    Only called from importers. Be aware that we overwrite an image if
    it exists!!
    """
    
    image = _getUrlImage(url)

    if not image:
        return 0

    photos = MPhoto.objects.filter(place=place)
    if len(photos)>0:
        photo = photos[0]
    else:
        photo = MPhoto()

    photo.name = name[:100]
    photo.place = place
    photo.def_img = True
    
    try:
        image_t = Image.open(ContentFile(image.read()))
    except:
        return photo
    image_t = image_t.convert("RGB")
    f=StringIO()
    image_t.save(f,"JPEG")
    f.seek(0)    
    
    unique_slug = url.split('/')[-1].replace(' ','_')
    
    photo.image.save(unique_slug, ContentFile(f.read()))

    try:
        photo.save()
    except:
        print 'Error with this image', photo.name

    return photo
    
    
def handle_uploaded_file(f,name):
    """ """
    photo = MPhoto()
    photo.title = name 
    photo.image = f
    photo.save()
    return photo

def handle_photo_file(f,title):
    """ """
    photo = Photo()
    photo.title = u'%s %s' % (time_slug_string(), title) 
    photo.title_slug = time_slug_string()
    photo.image = f
    photo.save()
    return photo
    


from django import forms
from arartekomaps.arartekouser.models import ArartekoUser
from django.contrib.auth.forms import PasswordResetForm


class PasswordReset(forms.Form):
    oldpassword = forms.CharField(widget=forms.PasswordInput(),max_length=100)
    password1 = forms.CharField(widget=forms.PasswordInput(),max_length=100)
    password2 = forms.CharField(widget=forms.PasswordInput(),max_length=100)

    def __init__(self, user, *args, **kwargs):
        self.user = user
        super(PasswordReset, self).__init__(*args, **kwargs)

    def clean_oldpassword(self):
        if self.clean_data.get('oldpassword') and not self.user.check_password(self.clean_data['oldpassword']):
            raise ValidationError('Please type your current password.')
        return self.clean_data['oldpassword']

    def clean_password2(self):
        if self.clean_data.get('password1') and self.clean_data.get('password2') and self.clean_data['password1'] != self.clean_data['password2']:
            raise ValidationError('The new passwords are not the same')
        return self.clean_data['password2']





from django.conf.urls.defaults import *
from piston.resource import Resource
from arartekomaps.api.handlers import *

location_handler = Resource(LocationsHandler)
category_handler = Resource(CategoriesHandler)
place_handler = Resource(PlaceHandler)
places_handler = Resource(PlacesHandler)
user_handler = Resource(UserHandler)
comment_handler = Resource(CommentHandler)
getcomment_handler = Resource(GetCommentHandler)

urlpatterns = patterns('',
   url(r'^1.0/get_cities$', location_handler),
   url(r'^1.0/get_categories$', category_handler),
   url(r'^1.0/get_place$', place_handler),
   url(r'^1.0/get_filtered_places$', places_handler),
   url(r'^1.0/get_comments$', getcomment_handler),
   url(r'^1.0/login_or_register$', user_handler),
   url(r'^1.0/post_comment$', comment_handler),
)